/* add-persona.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from add-persona.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
   Copyright (C) 2013 Canonical Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *          Renato Araujo Oliveira Filho <renato@canonical.com>
 *          Philip Withnall <philip.withnall@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <dummy-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gio/gio.h>
#include <gee.h>


#define TYPE_ADD_PERSONA_TESTS (add_persona_tests_get_type ())
#define ADD_PERSONA_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ADD_PERSONA_TESTS, AddPersonaTests))
#define ADD_PERSONA_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ADD_PERSONA_TESTS, AddPersonaTestsClass))
#define IS_ADD_PERSONA_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ADD_PERSONA_TESTS))
#define IS_ADD_PERSONA_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ADD_PERSONA_TESTS))
#define ADD_PERSONA_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ADD_PERSONA_TESTS, AddPersonaTestsClass))

typedef struct _AddPersonaTests AddPersonaTests;
typedef struct _AddPersonaTestsClass AddPersonaTestsClass;
typedef struct _AddPersonaTestsPrivate AddPersonaTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _AddPersonaTestsTestAddPersonaAsyncData AddPersonaTestsTestAddPersonaAsyncData;
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
typedef struct _AddPersonaTestsAddPersonaData AddPersonaTestsAddPersonaData;
typedef struct _AddPersonaTestsCheckPropertiesData AddPersonaTestsCheckPropertiesData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _AddPersonaTests {
	DummyTestTestCase parent_instance;
	AddPersonaTestsPrivate * priv;
};

struct _AddPersonaTestsClass {
	DummyTestTestCaseClass parent_class;
};

struct _AddPersonaTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gchar* _persona_fullname;
	gchar* _persona_nickname;
	gchar* _email_1;
	GHashTable* _properties_found;
	gchar* _avatar_path;
	gchar* _im_addr_1;
	gchar* _im_addr_2;
	gchar* _phone_1;
	gchar* _phone_1_type;
	gchar* _phone_2;
	gchar* _phone_2_type;
	FolksPostalAddressFieldDetails* _address;
	gchar* _po_box;
	gchar* _locality;
	gchar* _postal_code;
	gchar* _street;
	gchar* _extension;
	gchar* _country;
	gchar* _region;
	gchar* _family_name;
	gchar* _given_name;
	gchar* _note;
	FolksIndividual* _individual_received;
};

struct _AddPersonaTestsTestAddPersonaAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	AddPersonaTests* self;
	FolksIndividualAggregator* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	GError* e;
	GError* _tmp3_;
	const gchar* _tmp4_;
	GError * _inner_error_;
};

struct _AddPersonaTestsAddPersonaData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	AddPersonaTests* self;
	GHashTable* details;
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GHashTable* _tmp2_;
	GValue* v1;
	GValue _tmp3_;
	GValue _tmp4_;
	GValue* _tmp5_;
	GValue* _tmp6_;
	GValue* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	GValue* _tmp11_;
	GValue* v2;
	GValue _tmp12_;
	GValue _tmp13_;
	GValue* _tmp14_;
	GValue* _tmp15_;
	GeeHashSet* emails;
	GeeHashSet* _tmp16_;
	FolksEmailFieldDetails* email_1;
	const gchar* _tmp17_;
	FolksEmailFieldDetails* _tmp18_;
	GValue* _tmp19_;
	const gchar* _tmp20_;
	gchar* _tmp21_;
	GValue* _tmp22_;
	GValue* v3;
	GValue _tmp23_;
	GValue _tmp24_;
	GValue* _tmp25_;
	GValue* _tmp26_;
	GFileIcon* avatar;
	const gchar* _tmp27_;
	GFile* _tmp28_;
	GFile* _tmp29_;
	GFileIcon* _tmp30_;
	GFileIcon* _tmp31_;
	GValue* _tmp32_;
	const gchar* _tmp33_;
	gchar* _tmp34_;
	GValue* _tmp35_;
	GValue* v4;
	GValue _tmp36_;
	GValue _tmp37_;
	GValue* _tmp38_;
	GValue* _tmp39_;
	GeeHashMultiMap* im_fds;
	GeeHashMultiMap* _tmp40_;
	const gchar* _tmp41_;
	FolksImFieldDetails* _tmp42_;
	FolksImFieldDetails* _tmp43_;
	const gchar* _tmp44_;
	FolksImFieldDetails* _tmp45_;
	FolksImFieldDetails* _tmp46_;
	const gchar* _tmp47_;
	gchar* _tmp48_;
	GValue* _tmp49_;
	GValue* v5;
	GValue _tmp50_;
	GValue _tmp51_;
	GValue* _tmp52_;
	GValue* _tmp53_;
	GeeHashSet* phones;
	GeeHashSet* _tmp54_;
	FolksPhoneFieldDetails* phone_1;
	const gchar* _tmp55_;
	FolksPhoneFieldDetails* _tmp56_;
	const gchar* _tmp57_;
	FolksPhoneFieldDetails* phone_2;
	const gchar* _tmp58_;
	FolksPhoneFieldDetails* _tmp59_;
	const gchar* _tmp60_;
	GValue* _tmp61_;
	const gchar* _tmp62_;
	gchar* _tmp63_;
	GValue* _tmp64_;
	GValue* v6;
	GValue _tmp65_;
	GValue _tmp66_;
	GValue* _tmp67_;
	GValue* _tmp68_;
	GeeHashSet* pa_fds;
	GeeHashSet* _tmp69_;
	FolksPostalAddress* pa_a;
	const gchar* _tmp70_;
	const gchar* _tmp71_;
	const gchar* _tmp72_;
	const gchar* _tmp73_;
	const gchar* _tmp74_;
	const gchar* _tmp75_;
	const gchar* _tmp76_;
	FolksPostalAddress* _tmp77_;
	FolksPostalAddressFieldDetails* pa_fd_a;
	FolksPostalAddressFieldDetails* _tmp78_;
	GValue* _tmp79_;
	const gchar* _tmp80_;
	gchar* _tmp81_;
	GValue* _tmp82_;
	GValue* v7;
	GValue _tmp83_;
	GValue _tmp84_;
	GValue* _tmp85_;
	GValue* _tmp86_;
	FolksStructuredName* sname;
	const gchar* _tmp87_;
	const gchar* _tmp88_;
	FolksStructuredName* _tmp89_;
	GValue* _tmp90_;
	const gchar* _tmp91_;
	gchar* _tmp92_;
	GValue* _tmp93_;
	GValue* v8;
	GValue _tmp94_;
	GValue _tmp95_;
	GValue* _tmp96_;
	GValue* _tmp97_;
	GeeHashSet* notes;
	GeeHashSet* _tmp98_;
	FolksNoteFieldDetails* note;
	const gchar* _tmp99_;
	FolksNoteFieldDetails* _tmp100_;
	GValue* _tmp101_;
	const gchar* _tmp102_;
	gchar* _tmp103_;
	GValue* _tmp104_;
	GValue* v9;
	GValue _tmp105_;
	GValue _tmp106_;
	GValue* _tmp107_;
	GValue* _tmp108_;
	GDateTime* dobj;
	GDateTime* _tmp109_;
	GDateTime* _tmp110_;
	GDateTime* _tmp111_;
	GDateTime* _tmp112_;
	GValue* _tmp113_;
	const gchar* _tmp114_;
	gchar* _tmp115_;
	GValue* _tmp116_;
	GValue* v10;
	GValue _tmp117_;
	GValue _tmp118_;
	GValue* _tmp119_;
	GValue* _tmp120_;
	GeeHashSet* role_fds;
	GeeHashSet* _tmp121_;
	FolksRole* r1;
	FolksRole* _tmp122_;
	FolksRoleFieldDetails* role_fd1;
	FolksRoleFieldDetails* _tmp123_;
	GValue* _tmp124_;
	const gchar* _tmp125_;
	gchar* _tmp126_;
	GValue* _tmp127_;
	GValue* v11;
	GValue _tmp128_;
	GValue _tmp129_;
	GValue* _tmp130_;
	GValue* _tmp131_;
	GValue* _tmp132_;
	const gchar* _tmp133_;
	gchar* _tmp134_;
	GValue* _tmp135_;
	GValue* v12;
	GValue _tmp136_;
	GValue _tmp137_;
	GValue* _tmp138_;
	GValue* _tmp139_;
	GValue* _tmp140_;
	const gchar* _tmp141_;
	const gchar* _tmp142_;
	gchar* _tmp143_;
	GValue* _tmp144_;
	FolksIndividualAggregator* _tmp145_;
	FolksDummyPersonaStore* _tmp146_;
	FolksPersona* _tmp147_;
	FolksPersona* _tmp148_;
	GError* e;
	GError* _tmp149_;
	const gchar* _tmp150_;
	GError * _inner_error_;
};

struct _AddPersonaTestsCheckPropertiesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	AddPersonaTests* self;
	FolksIndividual* i;
	FolksIndividual* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	GHashTable* _tmp4_;
	gchar* _tmp5_;
	FolksIndividual* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	GHashTable* _tmp10_;
	gchar* _tmp11_;
	GeeIterator* _e_it;
	FolksIndividual* _tmp12_;
	GeeSet* _tmp13_;
	GeeSet* _tmp14_;
	GeeIterator* _tmp15_;
	GeeIterator* _tmp16_;
	gboolean _tmp17_;
	FolksEmailFieldDetails* e;
	GeeIterator* _tmp18_;
	gpointer _tmp19_;
	FolksEmailFieldDetails* _tmp20_;
	gconstpointer _tmp21_;
	const gchar* _tmp22_;
	const gchar* _tmp23_;
	GHashTable* _tmp24_;
	gchar* _tmp25_;
	GeeIterator* _proto_it;
	FolksIndividual* _tmp26_;
	GeeMultiMap* _tmp27_;
	GeeMultiMap* _tmp28_;
	GeeSet* _tmp29_;
	GeeSet* _tmp30_;
	GeeIterator* _tmp31_;
	GeeIterator* _tmp32_;
	GeeIterator* _tmp33_;
	gboolean _tmp34_;
	gchar* proto;
	GeeIterator* _tmp35_;
	gpointer _tmp36_;
	GeeCollection* im_fds;
	FolksIndividual* _tmp37_;
	GeeMultiMap* _tmp38_;
	GeeMultiMap* _tmp39_;
	const gchar* _tmp40_;
	GeeCollection* _tmp41_;
	GeeIterator* _im_fd_it;
	GeeCollection* _tmp42_;
	GeeIterator* _tmp43_;
	GeeIterator* _tmp44_;
	gboolean _tmp45_;
	FolksImFieldDetails* im_fd;
	GeeIterator* _tmp46_;
	gpointer _tmp47_;
	FolksImFieldDetails* _tmp48_;
	gconstpointer _tmp49_;
	const gchar* _tmp50_;
	const gchar* _tmp51_;
	GHashTable* _tmp52_;
	gchar* _tmp53_;
	FolksImFieldDetails* _tmp54_;
	gconstpointer _tmp55_;
	const gchar* _tmp56_;
	const gchar* _tmp57_;
	GHashTable* _tmp58_;
	gchar* _tmp59_;
	GeeIterator* _phone_fd_it;
	FolksIndividual* _tmp60_;
	GeeSet* _tmp61_;
	GeeSet* _tmp62_;
	GeeIterator* _tmp63_;
	GeeIterator* _tmp64_;
	gboolean _tmp65_;
	FolksPhoneFieldDetails* phone_fd;
	GeeIterator* _tmp66_;
	gpointer _tmp67_;
	FolksPhoneFieldDetails* phone_1;
	const gchar* _tmp68_;
	FolksPhoneFieldDetails* _tmp69_;
	FolksPhoneFieldDetails* _tmp70_;
	const gchar* _tmp71_;
	FolksPhoneFieldDetails* phone_2;
	const gchar* _tmp72_;
	FolksPhoneFieldDetails* _tmp73_;
	FolksPhoneFieldDetails* _tmp74_;
	const gchar* _tmp75_;
	FolksPhoneFieldDetails* _tmp76_;
	FolksPhoneFieldDetails* _tmp77_;
	gboolean _tmp78_;
	GHashTable* _tmp79_;
	gchar* _tmp80_;
	FolksPhoneFieldDetails* _tmp81_;
	FolksPhoneFieldDetails* _tmp82_;
	gboolean _tmp83_;
	GHashTable* _tmp84_;
	gchar* _tmp85_;
	GeeIterator* _pa_fd_it;
	FolksIndividual* _tmp86_;
	GeeSet* _tmp87_;
	GeeSet* _tmp88_;
	GeeIterator* _tmp89_;
	GeeIterator* _tmp90_;
	gboolean _tmp91_;
	FolksPostalAddressFieldDetails* pa_fd;
	GeeIterator* _tmp92_;
	gpointer _tmp93_;
	FolksPostalAddressFieldDetails* _tmp94_;
	FolksPostalAddressFieldDetails* _tmp95_;
	const gchar* _tmp96_;
	const gchar* _tmp97_;
	FolksPostalAddressFieldDetails* _tmp98_;
	FolksPostalAddressFieldDetails* _tmp99_;
	gboolean _tmp100_;
	GHashTable* _tmp101_;
	gchar* _tmp102_;
	gboolean _tmp103_;
	gboolean _tmp104_;
	FolksIndividual* _tmp105_;
	FolksStructuredName* _tmp106_;
	FolksStructuredName* _tmp107_;
	FolksIndividual* _tmp108_;
	FolksStructuredName* _tmp109_;
	FolksStructuredName* _tmp110_;
	const gchar* _tmp111_;
	const gchar* _tmp112_;
	const gchar* _tmp113_;
	FolksIndividual* _tmp114_;
	FolksStructuredName* _tmp115_;
	FolksStructuredName* _tmp116_;
	const gchar* _tmp117_;
	const gchar* _tmp118_;
	const gchar* _tmp119_;
	GHashTable* _tmp120_;
	gchar* _tmp121_;
	GeeIterator* _note_it;
	FolksIndividual* _tmp122_;
	GeeSet* _tmp123_;
	GeeSet* _tmp124_;
	GeeIterator* _tmp125_;
	GeeIterator* _tmp126_;
	gboolean _tmp127_;
	FolksNoteFieldDetails* note;
	GeeIterator* _tmp128_;
	gpointer _tmp129_;
	FolksNoteFieldDetails* _tmp130_;
	const gchar* _tmp131_;
	FolksNoteFieldDetails* _tmp132_;
	FolksNoteFieldDetails* _tmp133_;
	gboolean _tmp134_;
	gboolean _tmp135_;
	GHashTable* _tmp136_;
	gchar* _tmp137_;
	FolksIndividual* _tmp138_;
	GLoadableIcon* _tmp139_;
	GLoadableIcon* _tmp140_;
	GFileIcon* b;
	const gchar* _tmp141_;
	GFile* _tmp142_;
	GFile* _tmp143_;
	GFileIcon* _tmp144_;
	GFileIcon* _tmp145_;
	gboolean same;
	GFileIcon* _tmp146_;
	FolksIndividual* _tmp147_;
	GLoadableIcon* _tmp148_;
	GLoadableIcon* _tmp149_;
	gboolean _tmp150_;
	gboolean _tmp151_;
	GHashTable* _tmp152_;
	gchar* _tmp153_;
	FolksIndividual* _tmp154_;
	GDateTime* _tmp155_;
	GDateTime* _tmp156_;
	GDateTime* dobj;
	GDateTime* _tmp157_;
	GDateTime* _tmp158_;
	GDateTime* _tmp159_;
	GDateTime* _tmp160_;
	FolksIndividual* _tmp161_;
	GDateTime* _tmp162_;
	GDateTime* _tmp163_;
	GDateTime* _tmp164_;
	gboolean _tmp165_;
	GHashTable* _tmp166_;
	gchar* _tmp167_;
	GeeIterator* _role_fd_it;
	FolksIndividual* _tmp168_;
	GeeSet* _tmp169_;
	GeeSet* _tmp170_;
	GeeIterator* _tmp171_;
	GeeIterator* _tmp172_;
	gboolean _tmp173_;
	FolksRoleFieldDetails* role_fd;
	GeeIterator* _tmp174_;
	gpointer _tmp175_;
	FolksRole* r1;
	FolksRole* _tmp176_;
	FolksRole* _tmp177_;
	FolksRoleFieldDetails* role_fd_expected;
	FolksRole* _tmp178_;
	FolksRoleFieldDetails* _tmp179_;
	FolksRoleFieldDetails* _tmp180_;
	FolksRoleFieldDetails* _tmp181_;
	gboolean _tmp182_;
	GHashTable* _tmp183_;
	gchar* _tmp184_;
	FolksIndividual* _tmp185_;
	gboolean _tmp186_;
	gboolean _tmp187_;
	GHashTable* _tmp188_;
	gchar* _tmp189_;
};


static gpointer add_persona_tests_parent_class = NULL;

GType add_persona_tests_get_type (void) G_GNUC_CONST;
#define ADD_PERSONA_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_ADD_PERSONA_TESTS, AddPersonaTestsPrivate))
enum  {
	ADD_PERSONA_TESTS_DUMMY_PROPERTY
};
AddPersonaTests* add_persona_tests_new (void);
AddPersonaTests* add_persona_tests_construct (GType object_type);
void add_persona_tests_test_add_persona (AddPersonaTests* self);
static void _add_persona_tests_test_add_persona_folks_test_case_test_method (gpointer self);
static void _g_free0_ (gpointer var);
static void _add_persona_tests_test_add_persona_async (AddPersonaTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _add_persona_tests_test_add_persona_finish (AddPersonaTests* self, GAsyncResult* _res_);
static void _add_persona_tests_test_add_persona_async_data_free (gpointer _data);
static gboolean _add_persona_tests_test_add_persona_async_co (AddPersonaTestsTestAddPersonaAsyncData* _data_);
static void _add_persona_tests_individuals_changed_cb (AddPersonaTests* self, GeeMultiMap* changes);
static void __add_persona_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _add_persona_tests_test_add_persona_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _add_persona_tests_try_to_add (AddPersonaTests* self);
static void _add_persona_tests_add_persona_data_free (gpointer _data);
static void _add_persona_tests_add_persona (AddPersonaTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _add_persona_tests_add_persona_finish (AddPersonaTests* self, GAsyncResult* _res_);
static gboolean _add_persona_tests_add_persona_co (AddPersonaTestsAddPersonaData* _data_);
static void _vala_GValue_free (GValue* self);
static void __vala_GValue_free0_ (gpointer var);
static GValue* _g_value_dup (GValue* self);
static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
static void _add_persona_tests_add_persona_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static guint _add_persona_tests_track_individual (AddPersonaTests* self, FolksIndividual* i);
static void _add_persona_tests_notify_cb (AddPersonaTests* self, GObject* individual_obj, GParamSpec* ps);
static void __add_persona_tests_notify_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _add_persona_tests_check_properties (AddPersonaTests* self, FolksIndividual* i, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _add_persona_tests_check_properties_finish (AddPersonaTests* self, GAsyncResult* _res_);
static void _add_persona_tests_check_properties_data_free (gpointer _data);
static gboolean _add_persona_tests_check_properties_co (AddPersonaTestsCheckPropertiesData* _data_);
static void _add_persona_tests_check_properties_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _add_persona_tests_exit_if_all_properties_found (AddPersonaTests* self);
static void add_persona_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _add_persona_tests_test_add_persona_folks_test_case_test_method (gpointer self) {
#line 59 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	add_persona_tests_test_add_persona ((AddPersonaTests*) self);
#line 573 "add-persona.c"
}


AddPersonaTests* add_persona_tests_construct (GType object_type) {
	AddPersonaTests * self = NULL;
#line 57 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self = (AddPersonaTests*) dummy_test_test_case_construct (object_type, "AddPersonaTests");
#line 59 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "adding a persona", _add_persona_tests_test_add_persona_folks_test_case_test_method, self);
#line 55 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	return self;
#line 585 "add-persona.c"
}


AddPersonaTests* add_persona_tests_new (void) {
#line 55 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	return add_persona_tests_construct (TYPE_ADD_PERSONA_TESTS);
#line 592 "add-persona.c"
}


static void _g_free0_ (gpointer var) {
#line 86 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	var = (g_free (var), NULL);
#line 599 "add-persona.c"
}


void add_persona_tests_test_add_persona (AddPersonaTests* self) {
	GMainLoop* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	FolksPostalAddress* pa = NULL;
	const gchar* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	const gchar* _tmp17_ = NULL;
	const gchar* _tmp18_ = NULL;
	const gchar* _tmp19_ = NULL;
	FolksPostalAddress* _tmp20_ = NULL;
	FolksPostalAddress* _tmp21_ = NULL;
	FolksPostalAddressFieldDetails* _tmp22_ = NULL;
	FolksPostalAddressFieldDetails* _tmp23_ = NULL;
	GHashFunc _tmp24_ = NULL;
	GEqualFunc _tmp25_ = NULL;
	GHashTable* _tmp26_ = NULL;
	GHashTable* _tmp27_ = NULL;
	gchar* _tmp28_ = NULL;
	GHashTable* _tmp29_ = NULL;
	gchar* _tmp30_ = NULL;
	GHashTable* _tmp31_ = NULL;
	gchar* _tmp32_ = NULL;
	GHashTable* _tmp33_ = NULL;
	gchar* _tmp34_ = NULL;
	GHashTable* _tmp35_ = NULL;
	gchar* _tmp36_ = NULL;
	GHashTable* _tmp37_ = NULL;
	gchar* _tmp38_ = NULL;
	GHashTable* _tmp39_ = NULL;
	gchar* _tmp40_ = NULL;
	GHashTable* _tmp41_ = NULL;
	gchar* _tmp42_ = NULL;
	GHashTable* _tmp43_ = NULL;
	gchar* _tmp44_ = NULL;
	GHashTable* _tmp45_ = NULL;
	gchar* _tmp46_ = NULL;
	GHashTable* _tmp47_ = NULL;
	gchar* _tmp48_ = NULL;
	GHashTable* _tmp49_ = NULL;
	gchar* _tmp50_ = NULL;
	GHashTable* _tmp51_ = NULL;
	gchar* _tmp52_ = NULL;
	GHashTable* _tmp53_ = NULL;
	gchar* _tmp54_ = NULL;
	GMainLoop* _tmp55_ = NULL;
	GHashTable* _tmp56_ = NULL;
	GList* _tmp57_ = NULL;
#line 62 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_return_if_fail (self != NULL);
#line 64 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 64 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 64 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_main_loop = _tmp0_;
#line 65 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp1_ = g_strdup ("persona #1");
#line 65 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_persona_fullname);
#line 65 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_persona_fullname = _tmp1_;
#line 66 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp2_ = g_strdup ("Jo");
#line 66 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_persona_nickname);
#line 66 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_persona_nickname = _tmp2_;
#line 67 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp3_ = g_strdup ("someone-1@example.org");
#line 67 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_email_1);
#line 67 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_email_1 = _tmp3_;
#line 68 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp4_ = folks_test_utils_get_source_test_data ("data/avatar-01.jpg");
#line 68 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_avatar_path);
#line 68 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_avatar_path = _tmp4_;
#line 70 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp5_ = g_strdup ("someone-1@jabber.example.org");
#line 70 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_im_addr_1);
#line 70 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_im_addr_1 = _tmp5_;
#line 71 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp6_ = g_strdup ("someone-2@jabber.example.org");
#line 71 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_im_addr_2);
#line 71 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_im_addr_2 = _tmp6_;
#line 72 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp7_ = g_strdup ("12345");
#line 72 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_phone_1);
#line 72 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_phone_1 = _tmp7_;
#line 73 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp8_ = g_strdup (FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME);
#line 73 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_phone_1_type);
#line 73 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_phone_1_type = _tmp8_;
#line 74 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp9_ = g_strdup ("54321");
#line 74 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_phone_2);
#line 74 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_phone_2 = _tmp9_;
#line 75 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp10_ = g_strdup (FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_OTHER);
#line 75 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_phone_2_type);
#line 75 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_phone_2_type = _tmp10_;
#line 76 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp11_ = g_strdup ("family");
#line 76 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_family_name);
#line 76 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_family_name = _tmp11_;
#line 77 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp12_ = g_strdup ("given");
#line 77 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_given_name);
#line 77 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_given_name = _tmp12_;
#line 79 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp13_ = self->priv->_po_box;
#line 79 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp14_ = self->priv->_extension;
#line 79 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp15_ = self->priv->_street;
#line 79 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp16_ = self->priv->_locality;
#line 79 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp17_ = self->priv->_region;
#line 79 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp18_ = self->priv->_postal_code;
#line 79 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp19_ = self->priv->_country;
#line 79 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp20_ = folks_postal_address_new (_tmp13_, _tmp14_, _tmp15_, _tmp16_, _tmp17_, _tmp18_, _tmp19_, NULL, NULL);
#line 79 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	pa = _tmp20_;
#line 82 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp21_ = pa;
#line 82 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp22_ = folks_postal_address_field_details_new (_tmp21_, NULL);
#line 82 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (self->priv->_address);
#line 82 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_address = _tmp22_;
#line 83 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp23_ = self->priv->_address;
#line 83 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	folks_abstract_field_details_add_parameter ((FolksAbstractFieldDetails*) _tmp23_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME);
#line 86 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp24_ = g_str_hash;
#line 86 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp25_ = g_str_equal;
#line 86 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp26_ = g_hash_table_new_full (_tmp24_, _tmp25_, _g_free0_, NULL);
#line 86 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_hash_table_unref0 (self->priv->_properties_found);
#line 86 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_properties_found = _tmp26_;
#line 88 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp27_ = self->priv->_properties_found;
#line 88 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp28_ = g_strdup ("full_name");
#line 88 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_tmp27_, _tmp28_, (gpointer) ((gintptr) FALSE));
#line 89 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp29_ = self->priv->_properties_found;
#line 89 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp30_ = g_strdup ("nickname");
#line 89 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_tmp29_, _tmp30_, (gpointer) ((gintptr) FALSE));
#line 90 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp31_ = self->priv->_properties_found;
#line 90 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp32_ = g_strdup ("email-1");
#line 90 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_tmp31_, _tmp32_, (gpointer) ((gintptr) FALSE));
#line 91 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp33_ = self->priv->_properties_found;
#line 91 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp34_ = g_strdup ("avatar");
#line 91 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_tmp33_, _tmp34_, (gpointer) ((gintptr) FALSE));
#line 92 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp35_ = self->priv->_properties_found;
#line 92 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp36_ = g_strdup ("im-addr-1");
#line 92 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_tmp35_, _tmp36_, (gpointer) ((gintptr) FALSE));
#line 93 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp37_ = self->priv->_properties_found;
#line 93 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp38_ = g_strdup ("im-addr-2");
#line 93 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_tmp37_, _tmp38_, (gpointer) ((gintptr) FALSE));
#line 94 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp39_ = self->priv->_properties_found;
#line 94 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp40_ = g_strdup ("phone-1");
#line 94 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_tmp39_, _tmp40_, (gpointer) ((gintptr) FALSE));
#line 95 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp41_ = self->priv->_properties_found;
#line 95 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp42_ = g_strdup ("phone-2");
#line 95 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_tmp41_, _tmp42_, (gpointer) ((gintptr) FALSE));
#line 96 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp43_ = self->priv->_properties_found;
#line 96 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp44_ = g_strdup ("postal-address-1");
#line 96 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_tmp43_, _tmp44_, (gpointer) ((gintptr) FALSE));
#line 97 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp45_ = self->priv->_properties_found;
#line 97 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp46_ = g_strdup ("structured_name");
#line 97 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_tmp45_, _tmp46_, (gpointer) ((gintptr) FALSE));
#line 98 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp47_ = self->priv->_properties_found;
#line 98 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp48_ = g_strdup ("note");
#line 98 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_tmp47_, _tmp48_, (gpointer) ((gintptr) FALSE));
#line 99 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp49_ = self->priv->_properties_found;
#line 99 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp50_ = g_strdup ("birthday");
#line 99 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_tmp49_, _tmp50_, (gpointer) ((gintptr) FALSE));
#line 100 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp51_ = self->priv->_properties_found;
#line 100 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp52_ = g_strdup ("role-1");
#line 100 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_tmp51_, _tmp52_, (gpointer) ((gintptr) FALSE));
#line 101 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp53_ = self->priv->_properties_found;
#line 101 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp54_ = g_strdup ("is-favourite");
#line 101 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_tmp53_, _tmp54_, (gpointer) ((gintptr) FALSE));
#line 103 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_add_persona_tests_test_add_persona_async (self, NULL, NULL);
#line 105 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp55_ = self->priv->_main_loop;
#line 105 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	folks_test_utils_loop_run_with_timeout (_tmp55_, 5);
#line 107 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp56_ = self->priv->_properties_found;
#line 107 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp57_ = g_hash_table_get_values (_tmp56_);
#line 877 "add-persona.c"
	{
		GList* k_collection = NULL;
		GList* k_it = NULL;
#line 107 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		k_collection = _tmp57_;
#line 107 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		for (k_it = k_collection; k_it != NULL; k_it = k_it->next) {
#line 885 "add-persona.c"
			gboolean k = FALSE;
#line 107 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			k = (gboolean) ((gintptr) k_it->data);
#line 889 "add-persona.c"
			{
				gboolean _tmp58_ = FALSE;
#line 109 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_tmp58_ = k;
#line 109 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_vala_assert (_tmp58_, "k");
#line 896 "add-persona.c"
			}
		}
#line 107 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_list_free0 (k_collection);
#line 901 "add-persona.c"
	}
#line 62 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (pa);
#line 905 "add-persona.c"
}


static void _add_persona_tests_test_add_persona_async_data_free (gpointer _data) {
	AddPersonaTestsTestAddPersonaAsyncData* _data_;
	_data_ = _data;
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->self);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_slice_free (AddPersonaTestsTestAddPersonaAsyncData, _data_);
#line 916 "add-persona.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	return self ? g_object_ref (self) : NULL;
#line 923 "add-persona.c"
}


static void _add_persona_tests_test_add_persona_async (AddPersonaTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	AddPersonaTestsTestAddPersonaAsyncData* _data_;
	AddPersonaTests* _tmp0_ = NULL;
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_ = g_slice_new0 (AddPersonaTestsTestAddPersonaAsyncData);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _add_persona_tests_test_add_persona_async);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _add_persona_tests_test_add_persona_async_data_free);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->self = _tmp0_;
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_add_persona_tests_test_add_persona_async_co (_data_);
#line 942 "add-persona.c"
}


static void _add_persona_tests_test_add_persona_finish (AddPersonaTests* self, GAsyncResult* _res_) {
	AddPersonaTestsTestAddPersonaAsyncData* _data_;
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 950 "add-persona.c"
}


static void __add_persona_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 116 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_add_persona_tests_individuals_changed_cb ((AddPersonaTests*) self, changes);
#line 957 "add-persona.c"
}


static void _add_persona_tests_test_add_persona_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	AddPersonaTestsTestAddPersonaAsyncData* _data_;
#line 119 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_ = _user_data_;
#line 119 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_source_object_ = source_object;
#line 119 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_res_ = _res_;
#line 119 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_add_persona_tests_test_add_persona_async_co (_data_);
#line 971 "add-persona.c"
}


static gboolean _add_persona_tests_test_add_persona_async_co (AddPersonaTestsTestAddPersonaAsyncData* _data_) {
#line 113 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	switch (_data_->_state_) {
#line 113 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		case 0:
#line 980 "add-persona.c"
		goto _state_0;
#line 113 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		case 1:
#line 984 "add-persona.c"
		goto _state_1;
		default:
#line 113 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_assert_not_reached ();
#line 989 "add-persona.c"
	}
	_state_0:
#line 115 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp0_ = NULL;
#line 115 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp0_ = folks_individual_aggregator_dup ();
#line 115 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 115 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->self->priv->_aggregator = _data_->_tmp0_;
#line 116 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp1_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp1_ = _data_->self->priv->_aggregator;
#line 116 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_signal_connect_object (_data_->_tmp1_, "individuals-changed-detailed", (GCallback) __add_persona_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 1006 "add-persona.c"
	{
#line 119 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp2_ = NULL;
#line 119 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 119 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_state_ = 1;
#line 119 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		folks_individual_aggregator_prepare (_data_->_tmp2_, _add_persona_tests_test_add_persona_async_ready, _data_);
#line 119 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		return FALSE;
#line 1018 "add-persona.c"
		_state_1:
#line 119 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp2_, _data_->_res_, &_data_->_inner_error_);
#line 119 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		if (_data_->_inner_error_ != NULL) {
#line 1024 "add-persona.c"
			goto __catch0_g_error;
		}
#line 120 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_add_persona_tests_try_to_add (_data_->self);
#line 1029 "add-persona.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 117 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->e = _data_->_inner_error_;
#line 117 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_inner_error_ = NULL;
#line 124 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp3_ = NULL;
#line 124 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp3_ = _data_->e;
#line 124 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp4_ = NULL;
#line 124 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp4_ = _data_->_tmp3_->message;
#line 124 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_warning ("add-persona.vala:124: Error when calling prepare: %s\n", _data_->_tmp4_);
#line 117 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_error_free0 (_data_->e);
#line 1050 "add-persona.c"
	}
	__finally0:
#line 117 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	if (_data_->_inner_error_ != NULL) {
#line 117 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 117 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_clear_error (&_data_->_inner_error_);
#line 117 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		return FALSE;
#line 1061 "add-persona.c"
	}
#line 113 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	if (_data_->_state_ == 0) {
#line 113 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1067 "add-persona.c"
	} else {
#line 113 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1071 "add-persona.c"
	}
#line 113 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_object_unref (_data_->_async_result);
#line 113 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	return FALSE;
#line 1077 "add-persona.c"
}


static void _add_persona_tests_add_persona_data_free (gpointer _data) {
	AddPersonaTestsAddPersonaData* _data_;
	_data_ = _data;
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->self);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_slice_free (AddPersonaTestsAddPersonaData, _data_);
#line 1088 "add-persona.c"
}


static void _add_persona_tests_add_persona (AddPersonaTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	AddPersonaTestsAddPersonaData* _data_;
	AddPersonaTests* _tmp0_ = NULL;
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_ = g_slice_new0 (AddPersonaTestsAddPersonaData);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _add_persona_tests_add_persona);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _add_persona_tests_add_persona_data_free);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->self = _tmp0_;
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_add_persona_tests_add_persona_co (_data_);
#line 1107 "add-persona.c"
}


static void _add_persona_tests_add_persona_finish (AddPersonaTests* self, GAsyncResult* _res_) {
	AddPersonaTestsAddPersonaData* _data_;
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1115 "add-persona.c"
}


static void _vala_GValue_free (GValue* self) {
#line 130 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_unset (self);
#line 130 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_free (self);
#line 1124 "add-persona.c"
}


static void __vala_GValue_free0_ (gpointer var) {
#line 130 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	(var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL));
#line 1131 "add-persona.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 133 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 1138 "add-persona.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 133 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	return self ? _g_value_dup (self) : NULL;
#line 1145 "add-persona.c"
}


static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = folks_abstract_field_details_hash_static ((FolksAbstractFieldDetails*) v);
#line 139 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	return result;
#line 1154 "add-persona.c"
}


static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = folks_abstract_field_details_equal_static ((FolksAbstractFieldDetails*) a, (FolksAbstractFieldDetails*) b);
#line 139 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	return result;
#line 1163 "add-persona.c"
}


static void _add_persona_tests_add_persona_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	AddPersonaTestsAddPersonaData* _data_;
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_ = _user_data_;
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_source_object_ = source_object;
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_res_ = _res_;
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_add_persona_tests_add_persona_co (_data_);
#line 1177 "add-persona.c"
}


static gboolean _add_persona_tests_add_persona_co (AddPersonaTestsAddPersonaData* _data_) {
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	switch (_data_->_state_) {
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		case 0:
#line 1186 "add-persona.c"
		goto _state_0;
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		case 1:
#line 1190 "add-persona.c"
		goto _state_1;
		default:
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_assert_not_reached ();
#line 1195 "add-persona.c"
	}
	_state_0:
#line 130 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp0_ = NULL;
#line 130 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp0_ = g_str_hash;
#line 130 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp1_ = NULL;
#line 130 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp1_ = g_str_equal;
#line 130 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp2_ = NULL;
#line 130 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp2_ = g_hash_table_new_full (_data_->_tmp0_, _data_->_tmp1_, _g_free0_, __vala_GValue_free0_);
#line 130 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->details = _data_->_tmp2_;
#line 133 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp3_, 0, sizeof (GValue));
#line 133 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_init (&_data_->_tmp3_, G_TYPE_STRING);
#line 133 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp4_, 0, sizeof (GValue));
#line 133 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 133 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp5_ = NULL;
#line 133 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp5_ = __g_value_dup0 (&_data_->_tmp4_);
#line 133 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp6_ = NULL;
#line 133 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 133 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp4_) ? (g_value_unset (&_data_->_tmp4_), NULL) : NULL;
#line 133 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v1 = _data_->_tmp6_;
#line 134 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp7_ = NULL;
#line 134 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp7_ = _data_->v1;
#line 134 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp8_ = NULL;
#line 134 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp8_ = _data_->self->priv->_persona_fullname;
#line 134 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_set_string (_data_->_tmp7_, _data_->_tmp8_);
#line 135 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp9_ = NULL;
#line 135 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp9_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_FULL_NAME);
#line 135 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp10_ = NULL;
#line 135 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp10_ = g_strdup (_data_->_tmp9_);
#line 135 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp11_ = NULL;
#line 135 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp11_ = _data_->v1;
#line 135 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v1 = NULL;
#line 135 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp10_, _data_->_tmp11_);
#line 138 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp12_, 0, sizeof (GValue));
#line 138 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_init (&_data_->_tmp12_, GEE_TYPE_SET);
#line 138 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp13_, 0, sizeof (GValue));
#line 138 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 138 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp14_ = NULL;
#line 138 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp14_ = __g_value_dup0 (&_data_->_tmp13_);
#line 138 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp15_ = NULL;
#line 138 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp15_ = _data_->_tmp14_;
#line 138 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp13_) ? (g_value_unset (&_data_->_tmp13_), NULL) : NULL;
#line 138 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v2 = _data_->_tmp15_;
#line 139 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp16_ = NULL;
#line 139 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp16_ = gee_hash_set_new (FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 139 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->emails = _data_->_tmp16_;
#line 142 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp17_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp17_ = _data_->self->priv->_email_1;
#line 142 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp18_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp18_ = folks_email_field_details_new (_data_->_tmp17_, NULL);
#line 142 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->email_1 = _data_->_tmp18_;
#line 143 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _data_->email_1, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME);
#line 145 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->emails, _data_->email_1);
#line 146 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp19_ = NULL;
#line 146 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp19_ = _data_->v2;
#line 146 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_set_object (_data_->_tmp19_, (GObject*) _data_->emails);
#line 147 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp20_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp20_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_EMAIL_ADDRESSES);
#line 147 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp21_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp21_ = g_strdup (_data_->_tmp20_);
#line 147 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp22_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp22_ = _data_->v2;
#line 147 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v2 = NULL;
#line 147 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp21_, _data_->_tmp22_);
#line 151 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp23_, 0, sizeof (GValue));
#line 151 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_init (&_data_->_tmp23_, g_loadable_icon_get_type ());
#line 151 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp24_, 0, sizeof (GValue));
#line 151 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp24_ = _data_->_tmp23_;
#line 151 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp25_ = NULL;
#line 151 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp25_ = __g_value_dup0 (&_data_->_tmp24_);
#line 151 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp26_ = NULL;
#line 151 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp26_ = _data_->_tmp25_;
#line 151 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp24_) ? (g_value_unset (&_data_->_tmp24_), NULL) : NULL;
#line 151 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v3 = _data_->_tmp26_;
#line 152 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp27_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp27_ = _data_->self->priv->_avatar_path;
#line 152 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp28_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp28_ = g_file_new_for_path (_data_->_tmp27_);
#line 152 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp29_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp29_ = _data_->_tmp28_;
#line 152 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp30_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp30_ = (GFileIcon*) g_file_icon_new (_data_->_tmp29_);
#line 152 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp31_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp31_ = _data_->_tmp30_;
#line 152 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->_tmp29_);
#line 152 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->avatar = _data_->_tmp31_;
#line 153 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp32_ = NULL;
#line 153 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp32_ = _data_->v3;
#line 153 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_set_object (_data_->_tmp32_, (GObject*) _data_->avatar);
#line 154 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp33_ = NULL;
#line 154 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp33_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_AVATAR);
#line 154 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp34_ = NULL;
#line 154 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp34_ = g_strdup (_data_->_tmp33_);
#line 154 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp35_ = NULL;
#line 154 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp35_ = _data_->v3;
#line 154 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v3 = NULL;
#line 154 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp34_, _data_->_tmp35_);
#line 157 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp36_, 0, sizeof (GValue));
#line 157 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_init (&_data_->_tmp36_, GEE_TYPE_MULTI_MAP);
#line 157 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp37_, 0, sizeof (GValue));
#line 157 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp37_ = _data_->_tmp36_;
#line 157 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp38_ = NULL;
#line 157 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp38_ = __g_value_dup0 (&_data_->_tmp37_);
#line 157 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp39_ = NULL;
#line 157 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp39_ = _data_->_tmp38_;
#line 157 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp37_) ? (g_value_unset (&_data_->_tmp37_), NULL) : NULL;
#line 157 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v4 = _data_->_tmp39_;
#line 158 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp40_ = NULL;
#line 158 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp40_ = gee_hash_multi_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, FOLKS_TYPE_IM_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 158 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->im_fds = _data_->_tmp40_;
#line 159 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp41_ = NULL;
#line 159 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp41_ = _data_->self->priv->_im_addr_1;
#line 159 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp42_ = NULL;
#line 159 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp42_ = folks_im_field_details_new (_data_->_tmp41_, NULL);
#line 159 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp43_ = NULL;
#line 159 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp43_ = _data_->_tmp42_;
#line 159 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	gee_multi_map_set ((GeeMultiMap*) _data_->im_fds, "jabber", _data_->_tmp43_);
#line 159 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->_tmp43_);
#line 160 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp44_ = NULL;
#line 160 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp44_ = _data_->self->priv->_im_addr_2;
#line 160 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp45_ = NULL;
#line 160 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp45_ = folks_im_field_details_new (_data_->_tmp44_, NULL);
#line 160 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp46_ = NULL;
#line 160 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp46_ = _data_->_tmp45_;
#line 160 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	gee_multi_map_set ((GeeMultiMap*) _data_->im_fds, "yahoo", _data_->_tmp46_);
#line 160 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->_tmp46_);
#line 161 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_set_object (_data_->v4, (GObject*) _data_->im_fds);
#line 162 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp47_ = NULL;
#line 162 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp47_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_IM_ADDRESSES);
#line 162 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp48_ = NULL;
#line 162 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp48_ = g_strdup (_data_->_tmp47_);
#line 162 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp49_ = NULL;
#line 162 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp49_ = __g_value_dup0 (_data_->v4);
#line 162 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp48_, _data_->_tmp49_);
#line 165 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp50_, 0, sizeof (GValue));
#line 165 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_init (&_data_->_tmp50_, GEE_TYPE_SET);
#line 165 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp51_, 0, sizeof (GValue));
#line 165 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp51_ = _data_->_tmp50_;
#line 165 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp52_ = NULL;
#line 165 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp52_ = __g_value_dup0 (&_data_->_tmp51_);
#line 165 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp53_ = NULL;
#line 165 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp53_ = _data_->_tmp52_;
#line 165 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp51_) ? (g_value_unset (&_data_->_tmp51_), NULL) : NULL;
#line 165 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v5 = _data_->_tmp53_;
#line 166 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp54_ = NULL;
#line 166 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp54_ = gee_hash_set_new (FOLKS_TYPE_PHONE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 166 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->phones = _data_->_tmp54_;
#line 170 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp55_ = NULL;
#line 170 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp55_ = _data_->self->priv->_phone_1;
#line 170 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp56_ = NULL;
#line 170 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp56_ = folks_phone_field_details_new (_data_->_tmp55_, NULL);
#line 170 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->phone_1 = _data_->_tmp56_;
#line 171 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp57_ = NULL;
#line 171 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp57_ = _data_->self->priv->_phone_1_type;
#line 171 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _data_->phone_1, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, _data_->_tmp57_);
#line 173 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->phones, _data_->phone_1);
#line 174 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp58_ = NULL;
#line 174 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp58_ = _data_->self->priv->_phone_2;
#line 174 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp59_ = NULL;
#line 174 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp59_ = folks_phone_field_details_new (_data_->_tmp58_, NULL);
#line 174 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->phone_2 = _data_->_tmp59_;
#line 175 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp60_ = NULL;
#line 175 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp60_ = _data_->self->priv->_phone_2_type;
#line 175 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _data_->phone_2, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, _data_->_tmp60_);
#line 177 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->phones, _data_->phone_2);
#line 178 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp61_ = NULL;
#line 178 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp61_ = _data_->v5;
#line 178 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_set_object (_data_->_tmp61_, (GObject*) _data_->phones);
#line 179 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp62_ = NULL;
#line 179 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp62_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_PHONE_NUMBERS);
#line 179 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp63_ = NULL;
#line 179 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp63_ = g_strdup (_data_->_tmp62_);
#line 179 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp64_ = NULL;
#line 179 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp64_ = _data_->v5;
#line 179 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v5 = NULL;
#line 179 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp63_, _data_->_tmp64_);
#line 183 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp65_, 0, sizeof (GValue));
#line 183 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_init (&_data_->_tmp65_, GEE_TYPE_SET);
#line 183 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp66_, 0, sizeof (GValue));
#line 183 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp66_ = _data_->_tmp65_;
#line 183 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp67_ = NULL;
#line 183 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp67_ = __g_value_dup0 (&_data_->_tmp66_);
#line 183 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp68_ = NULL;
#line 183 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp68_ = _data_->_tmp67_;
#line 183 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp66_) ? (g_value_unset (&_data_->_tmp66_), NULL) : NULL;
#line 183 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v6 = _data_->_tmp68_;
#line 184 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp69_ = NULL;
#line 184 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp69_ = gee_hash_set_new (FOLKS_TYPE_POSTAL_ADDRESS_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 184 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->pa_fds = _data_->_tmp69_;
#line 188 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp70_ = NULL;
#line 188 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp70_ = _data_->self->priv->_po_box;
#line 188 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp71_ = NULL;
#line 188 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp71_ = _data_->self->priv->_extension;
#line 188 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp72_ = NULL;
#line 188 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp72_ = _data_->self->priv->_street;
#line 188 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp73_ = NULL;
#line 188 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp73_ = _data_->self->priv->_locality;
#line 188 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp74_ = NULL;
#line 188 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp74_ = _data_->self->priv->_region;
#line 188 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp75_ = NULL;
#line 188 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp75_ = _data_->self->priv->_postal_code;
#line 188 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp76_ = NULL;
#line 188 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp76_ = _data_->self->priv->_country;
#line 188 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp77_ = NULL;
#line 188 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp77_ = folks_postal_address_new (_data_->_tmp70_, _data_->_tmp71_, _data_->_tmp72_, _data_->_tmp73_, _data_->_tmp74_, _data_->_tmp75_, _data_->_tmp76_, NULL, NULL);
#line 188 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->pa_a = _data_->_tmp77_;
#line 191 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp78_ = NULL;
#line 191 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp78_ = folks_postal_address_field_details_new (_data_->pa_a, NULL);
#line 191 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->pa_fd_a = _data_->_tmp78_;
#line 192 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	folks_abstract_field_details_add_parameter ((FolksAbstractFieldDetails*) _data_->pa_fd_a, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME);
#line 194 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->pa_fds, _data_->pa_fd_a);
#line 195 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp79_ = NULL;
#line 195 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp79_ = _data_->v6;
#line 195 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_set_object (_data_->_tmp79_, (GObject*) _data_->pa_fds);
#line 196 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp80_ = NULL;
#line 196 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp80_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_POSTAL_ADDRESSES);
#line 196 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp81_ = NULL;
#line 196 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp81_ = g_strdup (_data_->_tmp80_);
#line 196 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp82_ = NULL;
#line 196 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp82_ = _data_->v6;
#line 196 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v6 = NULL;
#line 196 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp81_, _data_->_tmp82_);
#line 200 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp83_, 0, sizeof (GValue));
#line 200 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_init (&_data_->_tmp83_, FOLKS_TYPE_STRUCTURED_NAME);
#line 200 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp84_, 0, sizeof (GValue));
#line 200 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp84_ = _data_->_tmp83_;
#line 200 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp85_ = NULL;
#line 200 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp85_ = __g_value_dup0 (&_data_->_tmp84_);
#line 200 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp86_ = NULL;
#line 200 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp86_ = _data_->_tmp85_;
#line 200 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp84_) ? (g_value_unset (&_data_->_tmp84_), NULL) : NULL;
#line 200 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v7 = _data_->_tmp86_;
#line 201 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp87_ = NULL;
#line 201 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp87_ = _data_->self->priv->_family_name;
#line 201 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp88_ = NULL;
#line 201 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp88_ = _data_->self->priv->_given_name;
#line 201 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp89_ = NULL;
#line 201 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp89_ = folks_structured_name_new (_data_->_tmp87_, _data_->_tmp88_, NULL, NULL, NULL);
#line 201 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->sname = _data_->_tmp89_;
#line 203 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp90_ = NULL;
#line 203 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp90_ = _data_->v7;
#line 203 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_set_object (_data_->_tmp90_, (GObject*) _data_->sname);
#line 204 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp91_ = NULL;
#line 204 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp91_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_STRUCTURED_NAME);
#line 204 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp92_ = NULL;
#line 204 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp92_ = g_strdup (_data_->_tmp91_);
#line 204 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp93_ = NULL;
#line 204 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp93_ = _data_->v7;
#line 204 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v7 = NULL;
#line 204 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp92_, _data_->_tmp93_);
#line 208 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp94_, 0, sizeof (GValue));
#line 208 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_init (&_data_->_tmp94_, GEE_TYPE_SET);
#line 208 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp95_, 0, sizeof (GValue));
#line 208 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp95_ = _data_->_tmp94_;
#line 208 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp96_ = NULL;
#line 208 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp96_ = __g_value_dup0 (&_data_->_tmp95_);
#line 208 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp97_ = NULL;
#line 208 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp97_ = _data_->_tmp96_;
#line 208 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp95_) ? (g_value_unset (&_data_->_tmp95_), NULL) : NULL;
#line 208 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v8 = _data_->_tmp97_;
#line 209 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp98_ = NULL;
#line 209 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp98_ = gee_hash_set_new (FOLKS_TYPE_NOTE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 209 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->notes = _data_->_tmp98_;
#line 212 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp99_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp99_ = _data_->self->priv->_note;
#line 212 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp100_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp100_ = folks_note_field_details_new (_data_->_tmp99_, NULL, NULL);
#line 212 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->note = _data_->_tmp100_;
#line 213 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->notes, _data_->note);
#line 214 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp101_ = NULL;
#line 214 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp101_ = _data_->v8;
#line 214 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_set_object (_data_->_tmp101_, (GObject*) _data_->notes);
#line 215 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp102_ = NULL;
#line 215 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp102_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_NOTES);
#line 215 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp103_ = NULL;
#line 215 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp103_ = g_strdup (_data_->_tmp102_);
#line 215 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp104_ = NULL;
#line 215 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp104_ = _data_->v8;
#line 215 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v8 = NULL;
#line 215 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp103_, _data_->_tmp104_);
#line 219 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp105_, 0, sizeof (GValue));
#line 219 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_init (&_data_->_tmp105_, G_TYPE_DATE_TIME);
#line 219 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp106_, 0, sizeof (GValue));
#line 219 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp106_ = _data_->_tmp105_;
#line 219 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp107_ = NULL;
#line 219 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp107_ = __g_value_dup0 (&_data_->_tmp106_);
#line 219 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp108_ = NULL;
#line 219 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp108_ = _data_->_tmp107_;
#line 219 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp106_) ? (g_value_unset (&_data_->_tmp106_), NULL) : NULL;
#line 219 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v9 = _data_->_tmp108_;
#line 220 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp109_ = NULL;
#line 220 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp109_ = g_date_time_new_local (1980, 1, 1, 0, 0, 0.0);
#line 220 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp110_ = NULL;
#line 220 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp110_ = _data_->_tmp109_;
#line 220 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp111_ = NULL;
#line 220 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp111_ = g_date_time_to_utc (_data_->_tmp110_);
#line 220 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp112_ = NULL;
#line 220 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp112_ = _data_->_tmp111_;
#line 220 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_date_time_unref0 (_data_->_tmp110_);
#line 220 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->dobj = _data_->_tmp112_;
#line 221 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp113_ = NULL;
#line 221 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp113_ = _data_->v9;
#line 221 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_set_boxed (_data_->_tmp113_, _data_->dobj);
#line 222 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp114_ = NULL;
#line 222 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp114_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_BIRTHDAY);
#line 222 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp115_ = NULL;
#line 222 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp115_ = g_strdup (_data_->_tmp114_);
#line 222 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp116_ = NULL;
#line 222 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp116_ = _data_->v9;
#line 222 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v9 = NULL;
#line 222 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp115_, _data_->_tmp116_);
#line 225 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp117_, 0, sizeof (GValue));
#line 225 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_init (&_data_->_tmp117_, GEE_TYPE_SET);
#line 225 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp118_, 0, sizeof (GValue));
#line 225 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp118_ = _data_->_tmp117_;
#line 225 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp119_ = NULL;
#line 225 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp119_ = __g_value_dup0 (&_data_->_tmp118_);
#line 225 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp120_ = NULL;
#line 225 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp120_ = _data_->_tmp119_;
#line 225 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp118_) ? (g_value_unset (&_data_->_tmp118_), NULL) : NULL;
#line 225 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v10 = _data_->_tmp120_;
#line 226 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp121_ = NULL;
#line 226 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp121_ = gee_hash_set_new (FOLKS_TYPE_ROLE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 226 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->role_fds = _data_->_tmp121_;
#line 229 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp122_ = NULL;
#line 229 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp122_ = folks_role_new ("Dr.", "The Nut House Ltd", NULL);
#line 229 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->r1 = _data_->_tmp122_;
#line 230 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	folks_role_set_role (_data_->r1, "The Manager");
#line 231 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp123_ = NULL;
#line 231 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp123_ = folks_role_field_details_new (_data_->r1, NULL);
#line 231 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->role_fd1 = _data_->_tmp123_;
#line 232 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->role_fds, _data_->role_fd1);
#line 233 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp124_ = NULL;
#line 233 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp124_ = _data_->v10;
#line 233 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_set_object (_data_->_tmp124_, (GObject*) _data_->role_fds);
#line 234 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp125_ = NULL;
#line 234 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp125_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_ROLES);
#line 234 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp126_ = NULL;
#line 234 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp126_ = g_strdup (_data_->_tmp125_);
#line 234 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp127_ = NULL;
#line 234 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp127_ = _data_->v10;
#line 234 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v10 = NULL;
#line 234 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp126_, _data_->_tmp127_);
#line 237 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp128_, 0, sizeof (GValue));
#line 237 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_init (&_data_->_tmp128_, G_TYPE_BOOLEAN);
#line 237 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp129_, 0, sizeof (GValue));
#line 237 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp129_ = _data_->_tmp128_;
#line 237 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp130_ = NULL;
#line 237 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp130_ = __g_value_dup0 (&_data_->_tmp129_);
#line 237 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp131_ = NULL;
#line 237 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp131_ = _data_->_tmp130_;
#line 237 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp129_) ? (g_value_unset (&_data_->_tmp129_), NULL) : NULL;
#line 237 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v11 = _data_->_tmp131_;
#line 238 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp132_ = NULL;
#line 238 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp132_ = _data_->v11;
#line 238 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_set_boolean (_data_->_tmp132_, TRUE);
#line 239 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp133_ = NULL;
#line 239 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp133_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_IS_FAVOURITE);
#line 239 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp134_ = NULL;
#line 239 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp134_ = g_strdup (_data_->_tmp133_);
#line 239 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp135_ = NULL;
#line 239 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp135_ = _data_->v11;
#line 239 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v11 = NULL;
#line 239 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp134_, _data_->_tmp135_);
#line 243 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp136_, 0, sizeof (GValue));
#line 243 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_init (&_data_->_tmp136_, G_TYPE_STRING);
#line 243 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	memset (&_data_->_tmp137_, 0, sizeof (GValue));
#line 243 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp137_ = _data_->_tmp136_;
#line 243 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp138_ = NULL;
#line 243 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp138_ = __g_value_dup0 (&_data_->_tmp137_);
#line 243 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp139_ = NULL;
#line 243 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp139_ = _data_->_tmp138_;
#line 243 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp137_) ? (g_value_unset (&_data_->_tmp137_), NULL) : NULL;
#line 243 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v12 = _data_->_tmp139_;
#line 244 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp140_ = NULL;
#line 244 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp140_ = _data_->v12;
#line 244 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp141_ = NULL;
#line 244 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp141_ = _data_->self->priv->_persona_nickname;
#line 244 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_value_set_string (_data_->_tmp140_, _data_->_tmp141_);
#line 245 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp142_ = NULL;
#line 245 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp142_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_NICKNAME);
#line 245 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp143_ = NULL;
#line 245 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp143_ = g_strdup (_data_->_tmp142_);
#line 245 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp144_ = NULL;
#line 245 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp144_ = _data_->v12;
#line 245 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->v12 = NULL;
#line 245 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp143_, _data_->_tmp144_);
#line 1966 "add-persona.c"
	{
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp145_ = NULL;
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp145_ = _data_->self->priv->_aggregator;
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp146_ = NULL;
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp146_ = ((DummyTestTestCase*) _data_->self)->dummy_persona_store;
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_state_ = 1;
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		folks_individual_aggregator_add_persona_from_details (_data_->_tmp145_, NULL, (FolksPersonaStore*) _data_->_tmp146_, _data_->details, _add_persona_tests_add_persona_ready, _data_);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		return FALSE;
#line 1982 "add-persona.c"
		_state_1:
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp147_ = NULL;
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp147_ = folks_individual_aggregator_add_persona_from_details_finish (_data_->_tmp145_, _data_->_res_, &_data_->_inner_error_);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp148_ = NULL;
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp148_ = _data_->_tmp147_;
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->_tmp148_);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		if (_data_->_inner_error_ != NULL) {
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			if (_data_->_inner_error_->domain == FOLKS_INDIVIDUAL_AGGREGATOR_ERROR) {
#line 1998 "add-persona.c"
				goto __catch1_folks_individual_aggregator_error;
			}
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			__vala_GValue_free0 (_data_->v12);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			__vala_GValue_free0 (_data_->v11);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->role_fd1);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->r1);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->role_fds);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			__vala_GValue_free0 (_data_->v10);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_date_time_unref0 (_data_->dobj);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			__vala_GValue_free0 (_data_->v9);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->note);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->notes);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			__vala_GValue_free0 (_data_->v8);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->sname);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			__vala_GValue_free0 (_data_->v7);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->pa_fd_a);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->pa_a);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->pa_fds);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			__vala_GValue_free0 (_data_->v6);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->phone_2);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->phone_1);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->phones);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			__vala_GValue_free0 (_data_->v5);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->im_fds);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			__vala_GValue_free0 (_data_->v4);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->avatar);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			__vala_GValue_free0 (_data_->v3);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->email_1);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->emails);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			__vala_GValue_free0 (_data_->v2);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			__vala_GValue_free0 (_data_->v1);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_hash_table_unref0 (_data_->details);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			g_clear_error (&_data_->_inner_error_);
#line 250 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			return FALSE;
#line 2067 "add-persona.c"
		}
	}
	goto __finally1;
	__catch1_folks_individual_aggregator_error:
	{
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->e = _data_->_inner_error_;
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_inner_error_ = NULL;
#line 255 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp149_ = NULL;
#line 255 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp149_ = _data_->e;
#line 255 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp150_ = NULL;
#line 255 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp150_ = _data_->_tmp149_->message;
#line 255 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_warning ("add-persona.vala:255: [AddPersonaError] add_persona_from_details: %s\n", _data_->_tmp150_);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_error_free0 (_data_->e);
#line 2089 "add-persona.c"
	}
	__finally1:
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	if (_data_->_inner_error_ != NULL) {
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		__vala_GValue_free0 (_data_->v12);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		__vala_GValue_free0 (_data_->v11);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->role_fd1);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->r1);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->role_fds);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		__vala_GValue_free0 (_data_->v10);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_date_time_unref0 (_data_->dobj);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		__vala_GValue_free0 (_data_->v9);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->note);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->notes);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		__vala_GValue_free0 (_data_->v8);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->sname);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		__vala_GValue_free0 (_data_->v7);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->pa_fd_a);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->pa_a);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->pa_fds);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		__vala_GValue_free0 (_data_->v6);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->phone_2);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->phone_1);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->phones);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		__vala_GValue_free0 (_data_->v5);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->im_fds);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		__vala_GValue_free0 (_data_->v4);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->avatar);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		__vala_GValue_free0 (_data_->v3);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->email_1);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->emails);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		__vala_GValue_free0 (_data_->v2);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		__vala_GValue_free0 (_data_->v1);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_hash_table_unref0 (_data_->details);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_clear_error (&_data_->_inner_error_);
#line 248 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		return FALSE;
#line 2160 "add-persona.c"
	}
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	__vala_GValue_free0 (_data_->v12);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	__vala_GValue_free0 (_data_->v11);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->role_fd1);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->r1);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->role_fds);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	__vala_GValue_free0 (_data_->v10);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_date_time_unref0 (_data_->dobj);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	__vala_GValue_free0 (_data_->v9);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->note);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->notes);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	__vala_GValue_free0 (_data_->v8);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->sname);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	__vala_GValue_free0 (_data_->v7);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->pa_fd_a);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->pa_a);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->pa_fds);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	__vala_GValue_free0 (_data_->v6);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->phone_2);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->phone_1);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->phones);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	__vala_GValue_free0 (_data_->v5);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->im_fds);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	__vala_GValue_free0 (_data_->v4);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->avatar);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	__vala_GValue_free0 (_data_->v3);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->email_1);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->emails);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	__vala_GValue_free0 (_data_->v2);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	__vala_GValue_free0 (_data_->v1);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_hash_table_unref0 (_data_->details);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	if (_data_->_state_ == 0) {
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2226 "add-persona.c"
	} else {
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2230 "add-persona.c"
	}
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_object_unref (_data_->_async_result);
#line 128 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	return FALSE;
#line 2236 "add-persona.c"
}


static void _add_persona_tests_individuals_changed_cb (AddPersonaTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	guint num_replaces = 0U;
	GeeSet* _tmp13_ = NULL;
	gint _tmp14_ = 0;
	gint _tmp15_ = 0;
	guint _tmp16_ = 0U;
#line 260 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_return_if_fail (self != NULL);
#line 260 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_return_if_fail (changes != NULL);
#line 263 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp0_ = changes;
#line 263 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 263 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	added = _tmp1_;
#line 264 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp2_ = changes;
#line 264 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 264 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	removed = _tmp3_;
#line 266 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	num_replaces = (guint) 0;
#line 2270 "add-persona.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 268 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_tmp4_ = added;
#line 268 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 268 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_i_it = _tmp5_;
#line 268 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		while (TRUE) {
#line 2283 "add-persona.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			guint _tmp12_ = 0U;
#line 268 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_tmp6_ = _i_it;
#line 268 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 268 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			if (!_tmp7_) {
#line 268 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				break;
#line 2300 "add-persona.c"
			}
#line 268 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_tmp8_ = _i_it;
#line 268 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 268 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			i = (FolksIndividual*) _tmp9_;
#line 270 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_tmp10_ = i;
#line 270 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			if (_tmp10_ == NULL) {
#line 272 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_g_object_unref0 (i);
#line 272 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				continue;
#line 2316 "add-persona.c"
			}
#line 275 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_tmp11_ = i;
#line 275 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_tmp12_ = _add_persona_tests_track_individual (self, _tmp11_);
#line 275 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			num_replaces = _tmp12_;
#line 268 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (i);
#line 2326 "add-persona.c"
		}
#line 268 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_i_it);
#line 2330 "add-persona.c"
	}
#line 278 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp13_ = removed;
#line 278 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp14_ = gee_collection_get_size ((GeeCollection*) _tmp13_);
#line 278 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp15_ = _tmp14_;
#line 278 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp16_ = num_replaces;
#line 278 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_vala_assert (((guint) _tmp15_) <= (_tmp16_ + 1), "removed.size <= num_replaces + 1");
#line 260 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (removed);
#line 260 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (added);
#line 2346 "add-persona.c"
}


static void __add_persona_tests_notify_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 295 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_add_persona_tests_notify_cb ((AddPersonaTests*) self, _sender, pspec);
#line 2353 "add-persona.c"
}


static guint _add_persona_tests_track_individual (AddPersonaTests* self, FolksIndividual* i) {
	guint result = 0U;
	guint retval = 0U;
	FolksIndividual* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 281 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_return_val_if_fail (self != NULL, 0U);
#line 281 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_return_val_if_fail (i != NULL, 0U);
#line 283 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	retval = (guint) 0;
#line 285 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp0_ = i;
#line 285 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp1_ = folks_individual_get_is_user (_tmp0_);
#line 285 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp2_ = _tmp1_;
#line 285 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	if (_tmp2_ == FALSE) {
#line 2377 "add-persona.c"
		gboolean _tmp3_ = FALSE;
		FolksIndividual* _tmp4_ = NULL;
		FolksIndividual* _tmp11_ = NULL;
		FolksIndividual* _tmp15_ = NULL;
		FolksIndividual* _tmp16_ = NULL;
		guint _tmp17_ = 0U;
		FolksIndividual* _tmp18_ = NULL;
		FolksIndividual* _tmp19_ = NULL;
#line 289 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_tmp4_ = self->priv->_individual_received;
#line 289 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		if (_tmp4_ == NULL) {
#line 289 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_tmp3_ = TRUE;
#line 2392 "add-persona.c"
		} else {
			FolksIndividual* _tmp5_ = NULL;
			const gchar* _tmp6_ = NULL;
			const gchar* _tmp7_ = NULL;
			FolksIndividual* _tmp8_ = NULL;
			const gchar* _tmp9_ = NULL;
			const gchar* _tmp10_ = NULL;
#line 290 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_tmp5_ = self->priv->_individual_received;
#line 290 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_tmp6_ = folks_individual_get_id (_tmp5_);
#line 290 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_tmp7_ = _tmp6_;
#line 290 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_tmp8_ = i;
#line 290 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_tmp9_ = folks_individual_get_id (_tmp8_);
#line 290 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_tmp10_ = _tmp9_;
#line 290 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_tmp3_ = g_strcmp0 (_tmp7_, _tmp10_) == 0;
#line 2414 "add-persona.c"
		}
#line 289 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_vala_assert (_tmp3_, "this._individual_received == null ||               this._individual_received.id == i.id");
#line 293 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_tmp11_ = self->priv->_individual_received;
#line 293 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		if (_tmp11_ != NULL) {
#line 2422 "add-persona.c"
			FolksIndividual* _tmp12_ = NULL;
			guint _tmp13_ = 0U;
			GHashTable* _tmp14_ = NULL;
#line 295 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_tmp12_ = i;
#line 295 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			g_signal_parse_name ("notify", G_TYPE_OBJECT, &_tmp13_, NULL, FALSE);
#line 295 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			g_signal_handlers_disconnect_matched ((GObject*) _tmp12_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp13_, 0, NULL, (GCallback) __add_persona_tests_notify_cb_g_object_notify, self);
#line 297 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_tmp14_ = self->priv->_properties_found;
#line 297 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			g_hash_table_remove_all (_tmp14_);
#line 2436 "add-persona.c"
		}
#line 300 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_tmp15_ = i;
#line 300 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_tmp16_ = _g_object_ref0 (_tmp15_);
#line 300 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (self->priv->_individual_received);
#line 300 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		self->priv->_individual_received = _tmp16_;
#line 301 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_tmp17_ = retval;
#line 301 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		retval = _tmp17_ + 1;
#line 303 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_tmp18_ = i;
#line 303 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_signal_connect_object ((GObject*) _tmp18_, "notify", (GCallback) __add_persona_tests_notify_cb_g_object_notify, self, 0);
#line 305 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_tmp19_ = i;
#line 305 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_add_persona_tests_check_properties (self, _tmp19_, NULL, NULL);
#line 2458 "add-persona.c"
	}
#line 308 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	result = retval;
#line 308 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	return result;
#line 2464 "add-persona.c"
}


static void _add_persona_tests_notify_cb (AddPersonaTests* self, GObject* individual_obj, GParamSpec* ps) {
	FolksIndividual* i = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
#line 311 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_return_if_fail (self != NULL);
#line 311 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_return_if_fail (individual_obj != NULL);
#line 311 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_return_if_fail (ps != NULL);
#line 313 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp0_ = individual_obj;
#line 313 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 313 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	i = _tmp1_;
#line 314 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_add_persona_tests_check_properties (self, i, NULL, NULL);
#line 311 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (i);
#line 2488 "add-persona.c"
}


static void _add_persona_tests_try_to_add (AddPersonaTests* self) {
#line 317 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_return_if_fail (self != NULL);
#line 319 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_add_persona_tests_add_persona (self, NULL, NULL);
#line 2497 "add-persona.c"
}


static void _add_persona_tests_check_properties_data_free (gpointer _data) {
	AddPersonaTestsCheckPropertiesData* _data_;
	_data_ = _data;
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->i);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->self);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_slice_free (AddPersonaTestsCheckPropertiesData, _data_);
#line 2510 "add-persona.c"
}


static void _add_persona_tests_check_properties (AddPersonaTests* self, FolksIndividual* i, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	AddPersonaTestsCheckPropertiesData* _data_;
	AddPersonaTests* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_ = g_slice_new0 (AddPersonaTestsCheckPropertiesData);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _add_persona_tests_check_properties);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _add_persona_tests_check_properties_data_free);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->self = _tmp0_;
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp1_ = i;
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (_data_->i);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->i = _tmp2_;
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_add_persona_tests_check_properties_co (_data_);
#line 2539 "add-persona.c"
}


static void _add_persona_tests_check_properties_finish (AddPersonaTests* self, GAsyncResult* _res_) {
	AddPersonaTestsCheckPropertiesData* _data_;
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2547 "add-persona.c"
}


static void _add_persona_tests_check_properties_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	AddPersonaTestsCheckPropertiesData* _data_;
#line 396 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_ = _user_data_;
#line 396 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_source_object_ = source_object;
#line 396 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_res_ = _res_;
#line 396 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_add_persona_tests_check_properties_co (_data_);
#line 2561 "add-persona.c"
}


static gboolean _add_persona_tests_check_properties_co (AddPersonaTestsCheckPropertiesData* _data_) {
#line 322 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	switch (_data_->_state_) {
#line 322 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		case 0:
#line 2570 "add-persona.c"
		goto _state_0;
#line 322 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		case 1:
#line 2574 "add-persona.c"
		goto _state_1;
		default:
#line 322 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_assert_not_reached ();
#line 2579 "add-persona.c"
	}
	_state_0:
#line 324 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp0_ = NULL;
#line 324 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp0_ = _data_->i;
#line 324 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp1_ = NULL;
#line 324 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp1_ = folks_name_details_get_full_name ((FolksNameDetails*) _data_->_tmp0_);
#line 324 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp2_ = NULL;
#line 324 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 324 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp3_ = NULL;
#line 324 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp3_ = _data_->self->priv->_persona_fullname;
#line 324 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	if (g_strcmp0 (_data_->_tmp2_, _data_->_tmp3_) == 0) {
#line 325 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp4_ = NULL;
#line 325 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp4_ = _data_->self->priv->_properties_found;
#line 325 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp5_ = NULL;
#line 325 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp5_ = g_strdup ("full_name");
#line 325 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_hash_table_replace (_data_->_tmp4_, _data_->_tmp5_, (gpointer) ((gintptr) TRUE));
#line 2610 "add-persona.c"
	}
#line 327 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp6_ = NULL;
#line 327 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp6_ = _data_->i;
#line 327 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp7_ = NULL;
#line 327 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp7_ = folks_name_details_get_nickname ((FolksNameDetails*) _data_->_tmp6_);
#line 327 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp8_ = NULL;
#line 327 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp8_ = _data_->_tmp7_;
#line 327 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp9_ = NULL;
#line 327 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp9_ = _data_->self->priv->_persona_nickname;
#line 327 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	if (g_strcmp0 (_data_->_tmp8_, _data_->_tmp9_) == 0) {
#line 329 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp10_ = NULL;
#line 329 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp10_ = _data_->self->priv->_properties_found;
#line 329 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp11_ = NULL;
#line 329 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp11_ = g_strdup ("nickname");
#line 329 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_hash_table_replace (_data_->_tmp10_, _data_->_tmp11_, (gpointer) ((gintptr) TRUE));
#line 2640 "add-persona.c"
	}
	{
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp12_ = NULL;
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp12_ = _data_->i;
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp13_ = NULL;
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp13_ = folks_email_details_get_email_addresses ((FolksEmailDetails*) _data_->_tmp12_);
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp14_ = NULL;
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp14_ = _data_->_tmp13_;
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp15_ = NULL;
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp15_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp14_);
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_e_it = _data_->_tmp15_;
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		while (TRUE) {
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp16_ = NULL;
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp16_ = _data_->_e_it;
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp17_ = FALSE;
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp17_ = gee_iterator_next (_data_->_tmp16_);
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			if (!_data_->_tmp17_) {
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				break;
#line 2675 "add-persona.c"
			}
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp18_ = NULL;
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp18_ = _data_->_e_it;
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp19_ = NULL;
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp19_ = gee_iterator_get (_data_->_tmp18_);
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->e = (FolksEmailFieldDetails*) _data_->_tmp19_;
#line 334 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp20_ = NULL;
#line 334 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp20_ = _data_->e;
#line 334 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp21_ = NULL;
#line 334 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp21_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _data_->_tmp20_);
#line 334 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp22_ = NULL;
#line 334 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp22_ = _data_->_tmp21_;
#line 334 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp23_ = NULL;
#line 334 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp23_ = _data_->self->priv->_email_1;
#line 334 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			if (g_strcmp0 ((const gchar*) _data_->_tmp22_, _data_->_tmp23_) == 0) {
#line 336 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp24_ = NULL;
#line 336 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp24_ = _data_->self->priv->_properties_found;
#line 336 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp25_ = NULL;
#line 336 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp25_ = g_strdup ("email-1");
#line 336 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				g_hash_table_replace (_data_->_tmp24_, _data_->_tmp25_, (gpointer) ((gintptr) TRUE));
#line 2715 "add-persona.c"
			}
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->e);
#line 2719 "add-persona.c"
		}
#line 332 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->_e_it);
#line 2723 "add-persona.c"
	}
	{
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp26_ = NULL;
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp26_ = _data_->i;
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp27_ = NULL;
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp27_ = folks_im_details_get_im_addresses ((FolksImDetails*) _data_->_tmp26_);
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp28_ = NULL;
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp28_ = _data_->_tmp27_;
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp29_ = NULL;
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp29_ = gee_multi_map_get_keys (_data_->_tmp28_);
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp30_ = NULL;
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp30_ = _data_->_tmp29_;
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp31_ = NULL;
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp31_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp30_);
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp32_ = NULL;
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp32_ = _data_->_tmp31_;
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->_tmp30_);
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_proto_it = _data_->_tmp32_;
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		while (TRUE) {
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp33_ = NULL;
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp33_ = _data_->_proto_it;
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp34_ = FALSE;
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp34_ = gee_iterator_next (_data_->_tmp33_);
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			if (!_data_->_tmp34_) {
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				break;
#line 2772 "add-persona.c"
			}
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp35_ = NULL;
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp35_ = _data_->_proto_it;
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp36_ = NULL;
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp36_ = gee_iterator_get (_data_->_tmp35_);
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->proto = (gchar*) _data_->_tmp36_;
#line 342 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp37_ = NULL;
#line 342 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp37_ = _data_->i;
#line 342 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp38_ = NULL;
#line 342 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp38_ = folks_im_details_get_im_addresses ((FolksImDetails*) _data_->_tmp37_);
#line 342 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp39_ = NULL;
#line 342 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp39_ = _data_->_tmp38_;
#line 342 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp40_ = NULL;
#line 342 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp40_ = _data_->proto;
#line 342 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp41_ = NULL;
#line 342 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp41_ = gee_multi_map_get (_data_->_tmp39_, _data_->_tmp40_);
#line 342 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->im_fds = _data_->_tmp41_;
#line 2806 "add-persona.c"
			{
#line 343 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp42_ = NULL;
#line 343 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp42_ = _data_->im_fds;
#line 343 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp43_ = NULL;
#line 343 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp43_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp42_);
#line 343 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_im_fd_it = _data_->_tmp43_;
#line 343 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				while (TRUE) {
#line 343 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp44_ = NULL;
#line 343 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp44_ = _data_->_im_fd_it;
#line 343 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp45_ = FALSE;
#line 343 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp45_ = gee_iterator_next (_data_->_tmp44_);
#line 343 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					if (!_data_->_tmp45_) {
#line 343 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
						break;
#line 2832 "add-persona.c"
					}
#line 343 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp46_ = NULL;
#line 343 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp46_ = _data_->_im_fd_it;
#line 343 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp47_ = NULL;
#line 343 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp47_ = gee_iterator_get (_data_->_tmp46_);
#line 343 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->im_fd = (FolksImFieldDetails*) _data_->_tmp47_;
#line 345 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp48_ = NULL;
#line 345 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp48_ = _data_->im_fd;
#line 345 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp49_ = NULL;
#line 345 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp49_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _data_->_tmp48_);
#line 345 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp50_ = NULL;
#line 345 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp50_ = _data_->_tmp49_;
#line 345 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp51_ = NULL;
#line 345 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp51_ = _data_->self->priv->_im_addr_1;
#line 345 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					if (g_strcmp0 ((const gchar*) _data_->_tmp50_, _data_->_tmp51_) == 0) {
#line 346 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
						_data_->_tmp52_ = NULL;
#line 346 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
						_data_->_tmp52_ = _data_->self->priv->_properties_found;
#line 346 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
						_data_->_tmp53_ = NULL;
#line 346 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
						_data_->_tmp53_ = g_strdup ("im-addr-1");
#line 346 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
						g_hash_table_replace (_data_->_tmp52_, _data_->_tmp53_, (gpointer) ((gintptr) TRUE));
#line 2872 "add-persona.c"
					} else {
#line 347 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
						_data_->_tmp54_ = NULL;
#line 347 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
						_data_->_tmp54_ = _data_->im_fd;
#line 347 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
						_data_->_tmp55_ = NULL;
#line 347 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
						_data_->_tmp55_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _data_->_tmp54_);
#line 347 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
						_data_->_tmp56_ = NULL;
#line 347 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
						_data_->_tmp56_ = _data_->_tmp55_;
#line 347 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
						_data_->_tmp57_ = NULL;
#line 347 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
						_data_->_tmp57_ = _data_->self->priv->_im_addr_2;
#line 347 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
						if (g_strcmp0 ((const gchar*) _data_->_tmp56_, _data_->_tmp57_) == 0) {
#line 348 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
							_data_->_tmp58_ = NULL;
#line 348 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
							_data_->_tmp58_ = _data_->self->priv->_properties_found;
#line 348 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
							_data_->_tmp59_ = NULL;
#line 348 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
							_data_->_tmp59_ = g_strdup ("im-addr-2");
#line 348 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
							g_hash_table_replace (_data_->_tmp58_, _data_->_tmp59_, (gpointer) ((gintptr) TRUE));
#line 2902 "add-persona.c"
						}
					}
#line 343 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_g_object_unref0 (_data_->im_fd);
#line 2907 "add-persona.c"
				}
#line 343 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_g_object_unref0 (_data_->_im_fd_it);
#line 2911 "add-persona.c"
			}
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->im_fds);
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_free0 (_data_->proto);
#line 2917 "add-persona.c"
		}
#line 340 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->_proto_it);
#line 2921 "add-persona.c"
	}
	{
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp60_ = NULL;
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp60_ = _data_->i;
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp61_ = NULL;
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp61_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _data_->_tmp60_);
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp62_ = NULL;
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp62_ = _data_->_tmp61_;
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp63_ = NULL;
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp63_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp62_);
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_phone_fd_it = _data_->_tmp63_;
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		while (TRUE) {
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp64_ = NULL;
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp64_ = _data_->_phone_fd_it;
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp65_ = FALSE;
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp65_ = gee_iterator_next (_data_->_tmp64_);
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			if (!_data_->_tmp65_) {
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				break;
#line 2956 "add-persona.c"
			}
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp66_ = NULL;
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp66_ = _data_->_phone_fd_it;
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp67_ = NULL;
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp67_ = gee_iterator_get (_data_->_tmp66_);
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->phone_fd = (FolksPhoneFieldDetails*) _data_->_tmp67_;
#line 354 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp68_ = NULL;
#line 354 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp68_ = _data_->self->priv->_phone_1;
#line 354 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp69_ = NULL;
#line 354 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp69_ = folks_phone_field_details_new (_data_->_tmp68_, NULL);
#line 354 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->phone_1 = _data_->_tmp69_;
#line 355 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp70_ = NULL;
#line 355 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp70_ = _data_->phone_1;
#line 355 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp71_ = NULL;
#line 355 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp71_ = _data_->self->priv->_phone_1_type;
#line 355 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _data_->_tmp70_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, _data_->_tmp71_);
#line 357 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp72_ = NULL;
#line 357 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp72_ = _data_->self->priv->_phone_2;
#line 357 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp73_ = NULL;
#line 357 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp73_ = folks_phone_field_details_new (_data_->_tmp72_, NULL);
#line 357 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->phone_2 = _data_->_tmp73_;
#line 358 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp74_ = NULL;
#line 358 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp74_ = _data_->phone_2;
#line 358 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp75_ = NULL;
#line 358 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp75_ = _data_->self->priv->_phone_2_type;
#line 358 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _data_->_tmp74_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, _data_->_tmp75_);
#line 361 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp76_ = NULL;
#line 361 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp76_ = _data_->phone_fd;
#line 361 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp77_ = NULL;
#line 361 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp77_ = _data_->phone_1;
#line 361 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp78_ = FALSE;
#line 361 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp78_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _data_->_tmp76_, (FolksAbstractFieldDetails*) _data_->_tmp77_);
#line 361 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			if (_data_->_tmp78_) {
#line 363 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp79_ = NULL;
#line 363 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp79_ = _data_->self->priv->_properties_found;
#line 363 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp80_ = NULL;
#line 363 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp80_ = g_strdup ("phone-1");
#line 363 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				g_hash_table_replace (_data_->_tmp79_, _data_->_tmp80_, (gpointer) ((gintptr) TRUE));
#line 3032 "add-persona.c"
			} else {
#line 365 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp81_ = NULL;
#line 365 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp81_ = _data_->phone_fd;
#line 365 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp82_ = NULL;
#line 365 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp82_ = _data_->phone_2;
#line 365 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp83_ = FALSE;
#line 365 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp83_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _data_->_tmp81_, (FolksAbstractFieldDetails*) _data_->_tmp82_);
#line 365 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				if (_data_->_tmp83_) {
#line 367 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp84_ = NULL;
#line 367 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp84_ = _data_->self->priv->_properties_found;
#line 367 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp85_ = NULL;
#line 367 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_data_->_tmp85_ = g_strdup ("phone-2");
#line 367 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					g_hash_table_replace (_data_->_tmp84_, _data_->_tmp85_, (gpointer) ((gintptr) TRUE));
#line 3058 "add-persona.c"
				}
			}
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->phone_2);
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->phone_1);
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->phone_fd);
#line 3067 "add-persona.c"
		}
#line 352 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->_phone_fd_it);
#line 3071 "add-persona.c"
	}
	{
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp86_ = NULL;
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp86_ = _data_->i;
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp87_ = NULL;
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp87_ = folks_postal_address_details_get_postal_addresses ((FolksPostalAddressDetails*) _data_->_tmp86_);
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp88_ = NULL;
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp88_ = _data_->_tmp87_;
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp89_ = NULL;
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp89_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp88_);
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_pa_fd_it = _data_->_tmp89_;
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		while (TRUE) {
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp90_ = NULL;
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp90_ = _data_->_pa_fd_it;
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp91_ = FALSE;
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp91_ = gee_iterator_next (_data_->_tmp90_);
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			if (!_data_->_tmp91_) {
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				break;
#line 3106 "add-persona.c"
			}
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp92_ = NULL;
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp92_ = _data_->_pa_fd_it;
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp93_ = NULL;
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp93_ = gee_iterator_get (_data_->_tmp92_);
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->pa_fd = (FolksPostalAddressFieldDetails*) _data_->_tmp93_;
#line 373 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp94_ = NULL;
#line 373 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp94_ = _data_->self->priv->_address;
#line 373 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp95_ = NULL;
#line 373 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp95_ = _data_->pa_fd;
#line 373 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp96_ = NULL;
#line 373 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp96_ = folks_abstract_field_details_get_id ((FolksAbstractFieldDetails*) _data_->_tmp95_);
#line 373 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp97_ = NULL;
#line 373 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp97_ = _data_->_tmp96_;
#line 373 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			folks_abstract_field_details_set_id ((FolksAbstractFieldDetails*) _data_->_tmp94_, _data_->_tmp97_);
#line 374 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp98_ = NULL;
#line 374 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp98_ = _data_->pa_fd;
#line 374 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp99_ = NULL;
#line 374 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp99_ = _data_->self->priv->_address;
#line 374 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp100_ = FALSE;
#line 374 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp100_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _data_->_tmp98_, (FolksAbstractFieldDetails*) _data_->_tmp99_);
#line 374 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			if (_data_->_tmp100_) {
#line 375 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp101_ = NULL;
#line 375 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp101_ = _data_->self->priv->_properties_found;
#line 375 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp102_ = NULL;
#line 375 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp102_ = g_strdup ("postal-address-1");
#line 375 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				g_hash_table_replace (_data_->_tmp101_, _data_->_tmp102_, (gpointer) ((gintptr) TRUE));
#line 3160 "add-persona.c"
			}
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->pa_fd);
#line 3164 "add-persona.c"
		}
#line 371 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->_pa_fd_it);
#line 3168 "add-persona.c"
	}
#line 378 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp105_ = NULL;
#line 378 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp105_ = _data_->i;
#line 378 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp106_ = NULL;
#line 378 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp106_ = folks_name_details_get_structured_name ((FolksNameDetails*) _data_->_tmp105_);
#line 378 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp107_ = NULL;
#line 378 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp107_ = _data_->_tmp106_;
#line 378 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	if (_data_->_tmp107_ != NULL) {
#line 379 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp108_ = NULL;
#line 379 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp108_ = _data_->i;
#line 379 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp109_ = NULL;
#line 379 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp109_ = folks_name_details_get_structured_name ((FolksNameDetails*) _data_->_tmp108_);
#line 379 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp110_ = NULL;
#line 379 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp110_ = _data_->_tmp109_;
#line 379 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp111_ = NULL;
#line 379 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp111_ = folks_structured_name_get_family_name (_data_->_tmp110_);
#line 379 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp112_ = NULL;
#line 379 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp112_ = _data_->_tmp111_;
#line 379 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp113_ = NULL;
#line 379 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp113_ = _data_->self->priv->_family_name;
#line 379 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp104_ = g_strcmp0 (_data_->_tmp112_, _data_->_tmp113_) == 0;
#line 3210 "add-persona.c"
	} else {
#line 378 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp104_ = FALSE;
#line 3214 "add-persona.c"
	}
#line 378 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	if (_data_->_tmp104_) {
#line 380 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp114_ = NULL;
#line 380 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp114_ = _data_->i;
#line 380 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp115_ = NULL;
#line 380 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp115_ = folks_name_details_get_structured_name ((FolksNameDetails*) _data_->_tmp114_);
#line 380 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp116_ = NULL;
#line 380 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp116_ = _data_->_tmp115_;
#line 380 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp117_ = NULL;
#line 380 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp117_ = folks_structured_name_get_given_name (_data_->_tmp116_);
#line 380 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp118_ = NULL;
#line 380 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp118_ = _data_->_tmp117_;
#line 380 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp119_ = NULL;
#line 380 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp119_ = _data_->self->priv->_given_name;
#line 380 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp103_ = g_strcmp0 (_data_->_tmp118_, _data_->_tmp119_) == 0;
#line 3244 "add-persona.c"
	} else {
#line 378 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp103_ = FALSE;
#line 3248 "add-persona.c"
	}
#line 378 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	if (_data_->_tmp103_) {
#line 381 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp120_ = NULL;
#line 381 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp120_ = _data_->self->priv->_properties_found;
#line 381 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp121_ = NULL;
#line 381 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp121_ = g_strdup ("structured_name");
#line 381 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_hash_table_replace (_data_->_tmp120_, _data_->_tmp121_, (gpointer) ((gintptr) TRUE));
#line 3262 "add-persona.c"
	}
	{
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp122_ = NULL;
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp122_ = _data_->i;
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp123_ = NULL;
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp123_ = folks_note_details_get_notes ((FolksNoteDetails*) _data_->_tmp122_);
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp124_ = NULL;
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp124_ = _data_->_tmp123_;
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp125_ = NULL;
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp125_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp124_);
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_note_it = _data_->_tmp125_;
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		while (TRUE) {
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp126_ = NULL;
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp126_ = _data_->_note_it;
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp127_ = FALSE;
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp127_ = gee_iterator_next (_data_->_tmp126_);
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			if (!_data_->_tmp127_) {
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				break;
#line 3297 "add-persona.c"
			}
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp128_ = NULL;
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp128_ = _data_->_note_it;
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp129_ = NULL;
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp129_ = gee_iterator_get (_data_->_tmp128_);
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->note = (FolksNoteFieldDetails*) _data_->_tmp129_;
#line 385 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp130_ = NULL;
#line 385 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp130_ = _data_->note;
#line 385 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp131_ = NULL;
#line 385 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp131_ = _data_->self->priv->_note;
#line 385 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp132_ = NULL;
#line 385 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp132_ = folks_note_field_details_new (_data_->_tmp131_, NULL, NULL);
#line 385 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp133_ = NULL;
#line 385 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp133_ = _data_->_tmp132_;
#line 385 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp134_ = FALSE;
#line 385 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp134_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _data_->_tmp130_, (FolksAbstractFieldDetails*) _data_->_tmp133_);
#line 385 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp135_ = FALSE;
#line 385 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp135_ = _data_->_tmp134_;
#line 385 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->_tmp133_);
#line 385 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			if (_data_->_tmp135_) {
#line 387 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp136_ = NULL;
#line 387 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp136_ = _data_->self->priv->_properties_found;
#line 387 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp137_ = NULL;
#line 387 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp137_ = g_strdup ("note");
#line 387 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				g_hash_table_replace (_data_->_tmp136_, _data_->_tmp137_, (gpointer) ((gintptr) TRUE));
#line 388 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_g_object_unref0 (_data_->note);
#line 388 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				break;
#line 3351 "add-persona.c"
			}
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->note);
#line 3355 "add-persona.c"
		}
#line 383 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->_note_it);
#line 3359 "add-persona.c"
	}
#line 392 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp138_ = NULL;
#line 392 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp138_ = _data_->i;
#line 392 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp139_ = NULL;
#line 392 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp139_ = folks_avatar_details_get_avatar ((FolksAvatarDetails*) _data_->_tmp138_);
#line 392 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp140_ = NULL;
#line 392 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp140_ = _data_->_tmp139_;
#line 392 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	if (_data_->_tmp140_ != NULL) {
#line 394 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp141_ = NULL;
#line 394 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp141_ = _data_->self->priv->_avatar_path;
#line 394 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp142_ = NULL;
#line 394 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp142_ = g_file_new_for_path (_data_->_tmp141_);
#line 394 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp143_ = NULL;
#line 394 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp143_ = _data_->_tmp142_;
#line 394 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp144_ = NULL;
#line 394 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp144_ = (GFileIcon*) g_file_icon_new (_data_->_tmp143_);
#line 394 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp145_ = NULL;
#line 394 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp145_ = _data_->_tmp144_;
#line 394 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->_tmp143_);
#line 394 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->b = _data_->_tmp145_;
#line 396 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp146_ = NULL;
#line 396 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp146_ = _data_->b;
#line 396 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp147_ = NULL;
#line 396 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp147_ = _data_->i;
#line 396 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp148_ = NULL;
#line 396 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp148_ = folks_avatar_details_get_avatar ((FolksAvatarDetails*) _data_->_tmp147_);
#line 396 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp149_ = NULL;
#line 396 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp149_ = _data_->_tmp148_;
#line 396 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_state_ = 1;
#line 396 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		folks_test_utils_loadable_icons_content_equal ((GLoadableIcon*) _data_->_tmp146_, _data_->_tmp149_, -1, _add_persona_tests_check_properties_ready, _data_);
#line 396 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		return FALSE;
#line 3421 "add-persona.c"
		_state_1:
#line 396 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp150_ = FALSE;
#line 396 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp150_ = folks_test_utils_loadable_icons_content_equal_finish (_data_->_res_);
#line 396 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->same = _data_->_tmp150_;
#line 398 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp151_ = FALSE;
#line 398 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp151_ = _data_->same;
#line 398 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		if (_data_->_tmp151_) {
#line 399 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp152_ = NULL;
#line 399 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp152_ = _data_->self->priv->_properties_found;
#line 399 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp153_ = NULL;
#line 399 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp153_ = g_strdup ("avatar");
#line 399 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			g_hash_table_replace (_data_->_tmp152_, _data_->_tmp153_, (gpointer) ((gintptr) TRUE));
#line 3445 "add-persona.c"
		}
#line 392 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->b);
#line 3449 "add-persona.c"
	}
#line 402 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp154_ = NULL;
#line 402 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp154_ = _data_->i;
#line 402 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp155_ = NULL;
#line 402 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp155_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _data_->_tmp154_);
#line 402 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp156_ = NULL;
#line 402 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp156_ = _data_->_tmp155_;
#line 402 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	if (_data_->_tmp156_ != NULL) {
#line 404 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp157_ = NULL;
#line 404 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp157_ = g_date_time_new_local (1980, 1, 1, 0, 0, 0.0);
#line 404 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp158_ = NULL;
#line 404 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp158_ = _data_->_tmp157_;
#line 404 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp159_ = NULL;
#line 404 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp159_ = g_date_time_to_utc (_data_->_tmp158_);
#line 404 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp160_ = NULL;
#line 404 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp160_ = _data_->_tmp159_;
#line 404 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_date_time_unref0 (_data_->_tmp158_);
#line 404 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->dobj = _data_->_tmp160_;
#line 405 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp161_ = NULL;
#line 405 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp161_ = _data_->i;
#line 405 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp162_ = NULL;
#line 405 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp162_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _data_->_tmp161_);
#line 405 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp163_ = NULL;
#line 405 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp163_ = _data_->_tmp162_;
#line 405 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp164_ = NULL;
#line 405 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp164_ = _data_->dobj;
#line 405 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp165_ = FALSE;
#line 405 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp165_ = g_date_time_equal (_data_->_tmp163_, _data_->_tmp164_);
#line 405 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		if (_data_->_tmp165_) {
#line 406 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp166_ = NULL;
#line 406 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp166_ = _data_->self->priv->_properties_found;
#line 406 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp167_ = NULL;
#line 406 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp167_ = g_strdup ("birthday");
#line 406 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			g_hash_table_replace (_data_->_tmp166_, _data_->_tmp167_, (gpointer) ((gintptr) TRUE));
#line 3517 "add-persona.c"
		}
#line 402 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_date_time_unref0 (_data_->dobj);
#line 3521 "add-persona.c"
	}
	{
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp168_ = NULL;
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp168_ = _data_->i;
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp169_ = NULL;
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp169_ = folks_role_details_get_roles ((FolksRoleDetails*) _data_->_tmp168_);
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp170_ = NULL;
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp170_ = _data_->_tmp169_;
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp171_ = NULL;
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp171_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp170_);
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_role_fd_it = _data_->_tmp171_;
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		while (TRUE) {
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp172_ = NULL;
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp172_ = _data_->_role_fd_it;
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp173_ = FALSE;
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp173_ = gee_iterator_next (_data_->_tmp172_);
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			if (!_data_->_tmp173_) {
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				break;
#line 3556 "add-persona.c"
			}
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp174_ = NULL;
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp174_ = _data_->_role_fd_it;
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp175_ = NULL;
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp175_ = gee_iterator_get (_data_->_tmp174_);
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->role_fd = (FolksRoleFieldDetails*) _data_->_tmp175_;
#line 412 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp176_ = NULL;
#line 412 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp176_ = folks_role_new ("Dr.", "The Nut House Ltd", NULL);
#line 412 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->r1 = _data_->_tmp176_;
#line 413 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp177_ = NULL;
#line 413 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp177_ = _data_->r1;
#line 413 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			folks_role_set_role (_data_->_tmp177_, "The Manager");
#line 414 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp178_ = NULL;
#line 414 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp178_ = _data_->r1;
#line 414 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp179_ = NULL;
#line 414 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp179_ = folks_role_field_details_new (_data_->_tmp178_, NULL);
#line 414 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->role_fd_expected = _data_->_tmp179_;
#line 415 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp180_ = NULL;
#line 415 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp180_ = _data_->role_fd;
#line 415 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp181_ = NULL;
#line 415 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp181_ = _data_->role_fd_expected;
#line 415 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp182_ = FALSE;
#line 415 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_data_->_tmp182_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _data_->_tmp180_, (FolksAbstractFieldDetails*) _data_->_tmp181_);
#line 415 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			if (_data_->_tmp182_) {
#line 416 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp183_ = NULL;
#line 416 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp183_ = _data_->self->priv->_properties_found;
#line 416 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp184_ = NULL;
#line 416 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_data_->_tmp184_ = g_strdup ("role-1");
#line 416 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				g_hash_table_replace (_data_->_tmp183_, _data_->_tmp184_, (gpointer) ((gintptr) TRUE));
#line 3614 "add-persona.c"
			}
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->role_fd_expected);
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->r1);
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			_g_object_unref0 (_data_->role_fd);
#line 3622 "add-persona.c"
		}
#line 410 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_object_unref0 (_data_->_role_fd_it);
#line 3626 "add-persona.c"
	}
#line 419 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp185_ = NULL;
#line 419 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp185_ = _data_->i;
#line 419 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp186_ = FALSE;
#line 419 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp186_ = folks_favourite_details_get_is_favourite ((FolksFavouriteDetails*) _data_->_tmp185_);
#line 419 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp187_ = FALSE;
#line 419 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_data_->_tmp187_ = _data_->_tmp186_;
#line 419 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	if (_data_->_tmp187_) {
#line 421 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp188_ = NULL;
#line 421 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp188_ = _data_->self->priv->_properties_found;
#line 421 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp189_ = NULL;
#line 421 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_data_->_tmp189_ = g_strdup ("is-favourite");
#line 421 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_hash_table_replace (_data_->_tmp188_, _data_->_tmp189_, (gpointer) ((gintptr) TRUE));
#line 3652 "add-persona.c"
	}
#line 424 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_add_persona_tests_exit_if_all_properties_found (_data_->self);
#line 322 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	if (_data_->_state_ == 0) {
#line 322 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3660 "add-persona.c"
	} else {
#line 322 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3664 "add-persona.c"
	}
#line 322 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_object_unref (_data_->_async_result);
#line 322 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	return FALSE;
#line 3670 "add-persona.c"
}


static void _add_persona_tests_exit_if_all_properties_found (AddPersonaTests* self) {
	GHashTable* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GMainLoop* _tmp6_ = NULL;
#line 427 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_return_if_fail (self != NULL);
#line 429 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp0_ = self->priv->_properties_found;
#line 429 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp1_ = g_hash_table_get_keys (_tmp0_);
#line 3684 "add-persona.c"
	{
		GList* k_collection = NULL;
		GList* k_it = NULL;
#line 429 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		k_collection = _tmp1_;
#line 429 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		for (k_it = k_collection; k_it != NULL; k_it = k_it->next) {
#line 3692 "add-persona.c"
			const gchar* k = NULL;
#line 429 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
			k = (const gchar*) k_it->data;
#line 3696 "add-persona.c"
			{
				gboolean v = FALSE;
				GHashTable* _tmp2_ = NULL;
				const gchar* _tmp3_ = NULL;
				gconstpointer _tmp4_ = NULL;
				gboolean _tmp5_ = FALSE;
#line 431 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_tmp2_ = self->priv->_properties_found;
#line 431 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_tmp3_ = k;
#line 431 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_tmp4_ = g_hash_table_lookup (_tmp2_, _tmp3_);
#line 431 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				v = (gboolean) ((gintptr) _tmp4_);
#line 432 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				_tmp5_ = v;
#line 432 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
				if (_tmp5_ == FALSE) {
#line 433 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					_g_list_free0 (k_collection);
#line 433 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
					return;
#line 3719 "add-persona.c"
				}
			}
		}
#line 429 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
		_g_list_free0 (k_collection);
#line 3725 "add-persona.c"
	}
#line 435 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp6_ = self->priv->_main_loop;
#line 435 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_main_loop_quit (_tmp6_);
#line 3731 "add-persona.c"
}


static void add_persona_tests_class_init (AddPersonaTestsClass * klass) {
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	add_persona_tests_parent_class = g_type_class_peek_parent (klass);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_type_class_add_private (klass, sizeof (AddPersonaTestsPrivate));
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	G_OBJECT_CLASS (klass)->finalize = add_persona_tests_finalize;
#line 3742 "add-persona.c"
}


static void add_persona_tests_instance_init (AddPersonaTests * self) {
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv = ADD_PERSONA_TESTS_GET_PRIVATE (self);
#line 43 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp0_ = g_strdup ("12345");
#line 43 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_po_box = _tmp0_;
#line 44 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp1_ = g_strdup ("locality");
#line 44 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_locality = _tmp1_;
#line 45 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp2_ = g_strdup ("code");
#line 45 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_postal_code = _tmp2_;
#line 46 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp3_ = g_strdup ("some street");
#line 46 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_street = _tmp3_;
#line 47 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp4_ = g_strdup ("some extension");
#line 47 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_extension = _tmp4_;
#line 48 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp5_ = g_strdup ("some country");
#line 48 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_country = _tmp5_;
#line 49 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp6_ = g_strdup ("some region");
#line 49 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_region = _tmp6_;
#line 52 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp7_ = g_strdup ("This is a note.");
#line 52 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self->priv->_note = _tmp7_;
#line 3789 "add-persona.c"
}


static void add_persona_tests_finalize (GObject* obj) {
	AddPersonaTests * self;
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_ADD_PERSONA_TESTS, AddPersonaTests);
#line 29 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 30 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 31 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_persona_fullname);
#line 32 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_persona_nickname);
#line 33 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_email_1);
#line 34 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_hash_table_unref0 (self->priv->_properties_found);
#line 35 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_avatar_path);
#line 36 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_im_addr_1);
#line 37 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_im_addr_2);
#line 38 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_phone_1);
#line 39 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_phone_1_type);
#line 40 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_phone_2);
#line 41 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_phone_2_type);
#line 42 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (self->priv->_address);
#line 43 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_po_box);
#line 44 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_locality);
#line 45 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_postal_code);
#line 46 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_street);
#line 47 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_extension);
#line 48 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_country);
#line 49 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_region);
#line 50 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_family_name);
#line 51 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_given_name);
#line 52 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_free0 (self->priv->_note);
#line 53 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (self->priv->_individual_received);
#line 27 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	G_OBJECT_CLASS (add_persona_tests_parent_class)->finalize (obj);
#line 3849 "add-persona.c"
}


GType add_persona_tests_get_type (void) {
	static volatile gsize add_persona_tests_type_id__volatile = 0;
	if (g_once_init_enter (&add_persona_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AddPersonaTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) add_persona_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AddPersonaTests), 0, (GInstanceInitFunc) add_persona_tests_instance_init, NULL };
		GType add_persona_tests_type_id;
		add_persona_tests_type_id = g_type_register_static (DUMMY_TEST_TYPE_TEST_CASE, "AddPersonaTests", &g_define_type_info, 0);
		g_once_init_leave (&add_persona_tests_type_id__volatile, add_persona_tests_type_id);
	}
	return add_persona_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	AddPersonaTests* tests = NULL;
	AddPersonaTests* _tmp0_ = NULL;
#line 441 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_test_init (&args_length1, &args, NULL);
#line 443 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_tmp0_ = add_persona_tests_new ();
#line 443 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	tests = _tmp0_;
#line 444 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 445 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	g_test_run ();
#line 446 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 448 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	result = 0;
#line 448 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	_g_object_unref0 (tests);
#line 448 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	return result;
#line 3887 "add-persona.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 439 "/opt/gnome3/source/folks/tests/dummy/add-persona.vala"
	return _vala_main (argv, argc);
#line 3897 "add-persona.c"
}



